import { computed, unref, defineComponent, openBlock, createElementBlock, normalizeClass, createCommentVNode, renderSlot, createBlock, resolveDynamicComponent, withCtx, createElementVNode, createTextVNode, toDisplayString, onMounted, ref, watch, toRef, Fragment, renderList, mergeProps, onBeforeUnmount, createVNode, withModifiers, normalizeProps, guardReactiveProps, withDirectives, isRef, vModelDynamic, normalizeStyle, vModelText } from 'vue';
import { v4 } from 'uuid';

var templateString = (template, value) => {
    const values = Array.isArray(value) ? value : [value];
    let result = undefined;
    if (!values.some(v => v === undefined)) {
        let templated = template;
        values.forEach((v, i) => {
            templated = templated.replace(`{${i}}`, v);
        });
        result = templated;
    }
    return result;
};

var useStringTemplate = (template, value) => ({
    templatedString: computed(() => templateString(unref(template), unref(value))),
});

var useFlush = (flush, classTemplate) => {
    const { templatedString } = useStringTemplate(classTemplate, 'flush');
    const flushClass = computed(() => unref(flush) ? unref(templatedString) : undefined);
    return { flushClass };
};
const flushProps = {
    flush: {
        type: Boolean,
        default: false,
    },
};

const idProps = {
    id: {
        type: String,
        /**
         * ID's that start with a numeric value are considered invalid query
         * selectors, thus prefix it with something non-numeric.
         */
        default: () => `owow-${v4()}`,
    },
};

var useClasses = (values) => ({
    classes: computed(() => unref(values)
        .filter((v, i, s) => !!v && s.indexOf(v) === i)),
});

const _hoisted_1$j = ["id"];
var script$D = /*#__PURE__*/ defineComponent({
    __name: 'Accordion',
    props: Object.assign(Object.assign({}, flushProps), idProps),
    setup(__props) {
        const props = __props;
        const { classes } = useClasses(computed(() => [
            useFlush(props.flush, 'accordion-{0}').flushClass.value,
        ]));
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", {
                id: _ctx.id,
                class: normalizeClass(["accordion", unref(classes)])
            }, [
                createCommentVNode("\n        @slot Displays the content of the accordion\n        @binding {string} parent-id The id of the parent accordion\n        "),
                renderSlot(_ctx.$slots, "default", { parentId: _ctx.id })
            ], 10 /* CLASS, PROPS */, _hoisted_1$j));
        };
    }
});

script$D.__file = "src/components/Accordion/Accordion.vue";

const _hoisted_1$i = { class: "accordion-item" };
const _hoisted_2$d = ["data-bs-target"];
const _hoisted_3$8 = ["id", "data-bs-parent"];
var script$C = /*#__PURE__*/ defineComponent({
    __name: 'AccordionItem',
    props: Object.assign(Object.assign({ 
        /**
         * The classes that will be forwarded to the body
         */
        bodyClass: {
            type: [String, Array, Object],
            default: undefined,
        }, 
        /**
         * The classes that will be forwarded to the button
         */
        buttonClass: {
            type: [String, Array, Object],
            default: undefined,
        }, 
        /**
         * The classes that will be forwarded to the collapse
         */
        collapseClass: {
            type: [String, Array, Object],
            default: undefined,
        }, 
        /**
         * The text that will be shown in the header
         */
        header: {
            type: String,
            default: undefined,
        }, 
        /**
         * The classes that will be forwarded to the header
         */
        headerClass: {
            type: [String, Array, Object],
            default: undefined,
        }, 
        /**
         * The html tag that will be used for the header
         */
        headerTag: {
            type: String,
            default: 'h2',
        } }, idProps), { 
        /**
         * The id of the parent `Accordion` component
         */
        parentId: {
            type: String,
            default: undefined,
        } }),
    setup(__props) {
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", _hoisted_1$i, [
                (openBlock(), createBlock(resolveDynamicComponent(__props.headerTag), {
                    class: normalizeClass(["accordion-header", __props.headerClass])
                }, {
                    default: withCtx(() => [
                        createElementVNode("button", {
                            class: normalizeClass(["accordion-button collapsed", __props.buttonClass]),
                            "data-bs-toggle": "collapse",
                            "data-bs-target": `#${_ctx.id}`
                        }, [
                            createCommentVNode(" @slot Displays the header of the accordion "),
                            renderSlot(_ctx.$slots, "header", {}, () => [
                                createTextVNode(toDisplayString(__props.header), 1 /* TEXT */)
                            ])
                        ], 10 /* CLASS, PROPS */, _hoisted_2$d)
                    ]),
                    _: 3 /* FORWARDED */
                }, 8 /* PROPS */, ["class"])),
                createElementVNode("div", {
                    id: `${_ctx.id}`,
                    class: normalizeClass(["accordion-collapse collapse", __props.collapseClass]),
                    "data-bs-parent": __props.parentId ? `#${__props.parentId}` : undefined
                }, [
                    createElementVNode("div", {
                        class: normalizeClass(["accordion-body", __props.bodyClass])
                    }, [
                        createCommentVNode(" @slot Displays the body of the accordion "),
                        renderSlot(_ctx.$slots, "default")
                    ], 2 /* CLASS */)
                ], 10 /* CLASS, PROPS */, _hoisted_3$8)
            ]));
        };
    }
});

script$C.__file = "src/components/AccordionItem/AccordionItem.vue";

const useBootstrapEmits = (element, events, emit, typeName) => {
    onMounted(() => {
        events.forEach((event) => {
            const eventCallback = () => emit(event);
            element.value.addEventListener(`${event}.bs.${typeName}`, eventCallback);
        });
    });
};

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

const useBootstrap = () => {
    const bootstrap = ref();
    onMounted(() => __awaiter(void 0, void 0, void 0, function* () { return document && (bootstrap.value = yield import('bootstrap')); }));
    return bootstrap;
};

// TODO: Better typehinting
const useBootstrapInstance = (type, element, options = {}) => {
    const bootstrap = useBootstrap();
    const bsInstance = ref();
    watch(bootstrap, () => {
        var _a, _b;
        if (element.value) {
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            bsInstance.value = (_a = bootstrap.value) === null || _a === void 0 ? void 0 : _a[type].getOrCreateInstance(((_b = element.value) === null || _b === void 0 ? void 0 : _b.$el) || element.value, options);
        }
    });
    return { bootstrap, bsInstance };
};

const variants = ['primary', 'secondary', 'success', 'danger', 'warning', 'info', 'light', 'dark', 'link'];
var useVariant = (variant, classTemplate) => {
    const { templatedString } = useStringTemplate(classTemplate, variant);
    return { variantClass: templatedString };
};
const variantProp = (defaultValue = 'primary') => {
    return {
        type: String,
        default: defaultValue,
        validator: (v) => v ? variants.includes(v) : true,
    };
};
const variantProps = {
    variant: variantProp(),
};

const alertEvents = ['close', 'closed'];
var script$B = /*#__PURE__*/ defineComponent({
    __name: 'Alert',
    props: variantProps,
    setup(__props, { expose, emit }) {
        const props = __props;
        const alert = ref();
        useBootstrapEmits(alert, alertEvents, emit, 'alert');
        const { bsInstance: bsAlert } = useBootstrapInstance('Alert', alert);
        const { classes } = useClasses(computed(() => [
            useVariant(props.variant, 'alert-{0}').variantClass.value,
        ]));
        expose({ bsAlert });
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", {
                ref_key: "alert",
                ref: alert,
                class: normalizeClass(["alert", unref(classes)])
            }, [
                createCommentVNode(" @slot Displays content inside the alert "),
                renderSlot(_ctx.$slots, "default")
            ], 2 /* CLASS */));
        };
    }
});

script$B.__file = "src/components/Alert/Alert.vue";

var script$A = /*#__PURE__*/ defineComponent({
    __name: 'Badge',
    props: Object.assign({ 
        /**
         * Indicates if the badge should be shown as a pill
         */
        pill: {
            type: Boolean,
            default: false,
        } }, variantProps),
    setup(__props) {
        const props = __props;
        const { classes } = useClasses(computed(() => [
            computed(() => props.pill ? 'rounded-pill' : undefined).value,
            useVariant(props.variant, 'bg-{0}').variantClass.value,
        ]));
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", {
                class: normalizeClass(["badge", unref(classes)])
            }, [
                createCommentVNode(" @slot Displays content inside the badge "),
                renderSlot(_ctx.$slots, "default")
            ], 2 /* CLASS */));
        };
    }
});

script$A.__file = "src/components/Badge/Badge.vue";

const _hoisted_1$h = { class: "breadcrumb" };

function render$1(_ctx, _cache) {
  return (openBlock(), createElementBlock("nav", null, [
    createElementVNode("ol", _hoisted_1$h, [
      createCommentVNode(" @slot Displays content inside the breadcrumb "),
      renderSlot(_ctx.$slots, "default")
    ])
  ]))
}

const script$z = {};


script$z.render = render$1;
script$z.__file = "src/components/Breadcrumb/Breadcrumb.vue";

var useActive = (value) => ({
    activeClass: computed(() => unref(value) ? 'active' : undefined),
});
const activeProps = {
    active: {
        type: Boolean,
        default: false,
    },
};

var script$y = /*#__PURE__*/ defineComponent({
    __name: 'BreadcrumbItem',
    props: Object.assign({}, activeProps),
    setup(__props) {
        const props = __props;
        const { classes } = useClasses(computed(() => [
            useActive(props.active).activeClass.value,
        ]));
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("li", {
                class: normalizeClass(["breadcrumb-item", unref(classes)])
            }, [
                createCommentVNode(" @slot Displays content inside the breadcrumb item "),
                renderSlot(_ctx.$slots, "default")
            ], 2 /* CLASS */));
        };
    }
});

script$y.__file = "src/components/BreadcrumbItem/BreadcrumbItem.vue";

var useDisabled = (value) => ({
    disabledClass: computed(() => unref(value) ? 'disabled' : undefined),
});
const disabledProps = {
    disabled: {
        type: Boolean,
        default: false,
    },
};

const sizes = ['sm', 'md', 'lg', 'xl'];
var useSize = (size, classTemplate) => {
    const { templatedString } = useStringTemplate(classTemplate, size);
    return { sizeClass: templatedString };
};
const sizeProps = {
    size: {
        type: String,
        default: 'md',
        validator: (v) => sizes.includes(v),
    },
};

var script$x = /*#__PURE__*/ defineComponent({
    __name: 'Button',
    props: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, disabledProps), { href: {
            type: String,
            default: undefined,
        }, is: {
            type: String,
            default: undefined,
        }, 
        /**
         * Changes the button to an outline variant
         */
        outline: {
            type: Boolean,
            default: false,
        } }), sizeProps), { to: {
            type: [Object, String],
            default: undefined,
        } }), variantProps),
    setup(__props) {
        const props = __props;
        const variantClassTemplate = computed(() => `btn-${props.outline ? 'outline-' : ''}{0}`);
        const { classes } = useClasses(computed(() => [
            useDisabled(props.disabled).disabledClass.value,
            useSize(props.size, 'btn-{0}').sizeClass.value,
            useVariant(props.variant, variantClassTemplate).variantClass.value,
        ]));
        const is = computed(() => {
            if (props.is) {
                return props.is;
            }
            if (props.to) {
                return 'RouterLink';
            }
            if (props.href) {
                return 'a';
            }
            return 'button';
        });
        return (_ctx, _cache) => {
            return (openBlock(), createBlock(resolveDynamicComponent(unref(is)), {
                class: normalizeClass(["btn", unref(classes)]),
                disabled: _ctx.disabled,
                href: __props.href,
                to: __props.to
            }, {
                default: withCtx(() => [
                    createCommentVNode(" @slot Displays content inside the button "),
                    renderSlot(_ctx.$slots, "default")
                ]),
                _: 3 /* FORWARDED */
            }, 8 /* PROPS */, ["class", "disabled", "href", "to"]));
        };
    }
});

script$x.__file = "src/components/Button/Button.vue";

const _hoisted_1$g = ["disabled"];
var script$w = /*#__PURE__*/ defineComponent({
    __name: 'ButtonClose',
    props: Object.assign({}, disabledProps),
    setup(__props) {
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("button", {
                class: "btn-close",
                disabled: _ctx.disabled
            }, null, 8 /* PROPS */, _hoisted_1$g));
        };
    }
});

script$w.__file = "src/components/ButtonClose/ButtonClose.vue";

var script$v = /*#__PURE__*/ defineComponent({
    __name: 'ButtonGroup',
    props: Object.assign(Object.assign({}, sizeProps), { 
        /**
         * Stacks the buttons vertically
         */
        vertical: {
            type: Boolean,
            default: false,
        } }),
    setup(__props) {
        const props = __props;
        const { classes } = useClasses(computed(() => [
            computed(() => props.vertical ? 'btn-group-vertical' : 'btn-group').value,
            useSize(props.size, 'btn-group-{0}').sizeClass.value,
        ]));
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", {
                class: normalizeClass(unref(classes))
            }, [
                createCommentVNode(" @slot Displays content inside the button group "),
                renderSlot(_ctx.$slots, "default")
            ], 2 /* CLASS */));
        };
    }
});

script$v.__file = "src/components/ButtonGroup/ButtonGroup.vue";

const types$2 = ['border', 'grow'];
var script$u = /*#__PURE__*/ defineComponent({
    __name: 'Spinner',
    props: Object.assign(Object.assign(Object.assign({}, sizeProps), { 
        /**
         * The type of the spinner
         * @values 'border'|'grow'
         */
        type: {
            type: String,
            default: 'border',
            validator: (t) => types$2.includes(t),
        } }), variantProps),
    setup(__props) {
        const props = __props;
        const spinnerClass = useStringTemplate('spinner-{0}', toRef(props, 'type')).templatedString;
        const { classes } = useClasses(computed(() => [
            useSize(props.size, `${spinnerClass.value}-{0}`).sizeClass.value,
            spinnerClass.value,
            useVariant(props.variant, 'text-{0}').variantClass.value,
        ]));
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", {
                class: normalizeClass(unref(classes))
            }, null, 2 /* CLASS */));
        };
    }
});

script$u.__file = "src/components/Spinner/Spinner.vue";

const _hoisted_1$f = {
    key: 0,
    class: "me-2"
};
const _hoisted_2$c = {
    key: 1,
    class: "button-state-icon",
    "data-test": "success",
    fill: "currentColor",
    height: "1em",
    viewBox: "3 3 10 10",
    xmlns: "http://www.w3.org/2000/svg",
    width: "1em"
};
const _hoisted_3$7 = /*#__PURE__*/ createElementVNode("path", { d: "M10.97 4.97a.75.75 0 0 1 1.07 1.05l-3.99 4.99a.75.75 0 0 1-1.08.02L4.324 8.384a.75.75 0 1 1 1.06-1.06l2.094 2.093 3.473-4.425a.267.267 0 0 1 .02-.022z" }, null, -1 /* HOISTED */);
const _hoisted_4$4 = [
    _hoisted_3$7
];
const _hoisted_5$4 = {
    key: 2,
    class: "button-state-icon",
    "data-test": "error",
    fill: "currentColor",
    height: "1em",
    viewBox: "0 0 16 16",
    xmlns: "http://www.w3.org/2000/svg",
    width: "1em"
};
const _hoisted_6$3 = /*#__PURE__*/ createElementVNode("path", { d: "M8 15A7 7 0 1 1 8 1a7 7 0 0 1 0 14zm0 1A8 8 0 1 0 8 0a8 8 0 0 0 0 16z" }, null, -1 /* HOISTED */);
const _hoisted_7$2 = /*#__PURE__*/ createElementVNode("path", { d: "M7.002 11a1 1 0 1 1 2 0 1 1 0 0 1-2 0zM7.1 4.995a.905.905 0 1 1 1.8 0l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 4.995z" }, null, -1 /* HOISTED */);
const _hoisted_8$1 = [
    _hoisted_6$3,
    _hoisted_7$2
];
var script$t = /*#__PURE__*/ defineComponent({
    __name: 'ButtonState',
    props: {
        /**
         * Controls the error state of the button
         */
        error: {
            type: Boolean,
            default: false,
        },
        errorVariant: variantProp('danger'),
        /**
         * Controls the loading state of the button
         */
        loading: {
            type: Boolean,
            default: false,
        },
        /**
         * Controls the success state of the button
         */
        success: {
            type: Boolean,
            default: false,
        },
        successVariant: variantProp('success'),
        variant: variantProp(),
    },
    setup(__props) {
        const props = __props;
        const disabled = computed(() => props.loading);
        const variant = computed(() => {
            switch (true) {
                case props.success:
                    return props.successVariant;
                case props.error:
                    return props.errorVariant;
                default:
                    return props.variant;
            }
        });
        return (_ctx, _cache) => {
            return (openBlock(), createBlock(unref(script$x), {
                disabled: unref(disabled),
                variant: unref(variant)
            }, {
                default: withCtx(() => [
                    (__props.error || __props.loading || __props.success)
                        ? (openBlock(), createElementBlock("span", _hoisted_1$f, [
                            (__props.loading)
                                ? (openBlock(), createBlock(unref(script$u), {
                                    key: 0,
                                    size: "sm",
                                    variant: ""
                                }))
                                : createCommentVNode("v-if", true),
                            (__props.success)
                                ? (openBlock(), createElementBlock("svg", _hoisted_2$c, _hoisted_4$4))
                                : createCommentVNode("v-if", true),
                            (__props.error)
                                ? (openBlock(), createElementBlock("svg", _hoisted_5$4, _hoisted_8$1))
                                : createCommentVNode("v-if", true)
                        ]))
                        : createCommentVNode("v-if", true),
                    createCommentVNode(" @slot Displays content inside the button "),
                    renderSlot(_ctx.$slots, "default")
                ]),
                _: 3 /* FORWARDED */
            }, 8 /* PROPS */, ["disabled", "variant"]));
        };
    }
});

script$t.__file = "src/components/ButtonState/ButtonState.vue";

const _hoisted_1$e = { class: "card" };
const _hoisted_2$b = {
    key: 0,
    class: "card-header"
};
const _hoisted_3$6 = {
    key: 0,
    class: "card-title"
};
const _hoisted_4$3 = {
    key: 1,
    class: "card-subtitle"
};
const _hoisted_5$3 = {
    key: 2,
    class: "card-text"
};
const _hoisted_6$2 = {
    key: 1,
    class: "card-footer"
};
var script$s = /*#__PURE__*/ defineComponent({
    __name: 'Card',
    props: {
        /**
         * The text displayed in the footer. Will be overwritten by the user of the `footer` slot
         */
        footer: {
            type: String,
            default: undefined,
        },
        /**
         * The text displayed in the header. Will be overwritten by the user of the `header` slot
         */
        header: {
            type: String,
            default: undefined,
        },
        /**
         * Prevents the `.card-body` class from being added. Useful for when multiple card bodies are required
         */
        noBody: {
            type: Boolean,
            default: false,
        },
        /**
         * The subtitle displayed in the body. Will be overwritten by the user of the `default` slot
         */
        subtitle: {
            type: String,
            default: undefined,
        },
        /**
         * The text displayed in the body. Will be overwritten by the user of the `default` slot
         */
        text: {
            type: String,
            default: undefined,
        },
        /**
         * The title displayed in the body. Will be overwritten by the user of the `default` slot
         */
        title: {
            type: String,
            default: undefined,
        },
    },
    setup(__props) {
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", _hoisted_1$e, [
                (!!_ctx.$slots.header || !!__props.header)
                    ? (openBlock(), createElementBlock("div", _hoisted_2$b, [
                        createCommentVNode(" @slot Displays content inside the header of the card "),
                        renderSlot(_ctx.$slots, "header", {}, () => [
                            createTextVNode(toDisplayString(__props.header), 1 /* TEXT */)
                        ])
                    ]))
                    : createCommentVNode("v-if", true),
                createElementVNode("div", {
                    class: normalizeClass({ 'card-body': !__props.noBody })
                }, [
                    createCommentVNode(" @slot Displays content inside the body of the card "),
                    renderSlot(_ctx.$slots, "default", {}, () => [
                        (__props.title)
                            ? (openBlock(), createElementBlock("h5", _hoisted_3$6, toDisplayString(__props.title), 1 /* TEXT */))
                            : createCommentVNode("v-if", true),
                        (__props.subtitle)
                            ? (openBlock(), createElementBlock("h6", _hoisted_4$3, toDisplayString(__props.subtitle), 1 /* TEXT */))
                            : createCommentVNode("v-if", true),
                        (__props.text)
                            ? (openBlock(), createElementBlock("div", _hoisted_5$3, toDisplayString(__props.text), 1 /* TEXT */))
                            : createCommentVNode("v-if", true)
                    ])
                ], 2 /* CLASS */),
                (!!_ctx.$slots.footer || __props.footer)
                    ? (openBlock(), createElementBlock("div", _hoisted_6$2, [
                        createCommentVNode(" @slot Displays content inside the footer of the card "),
                        renderSlot(_ctx.$slots, "footer", {}, () => [
                            createTextVNode(toDisplayString(__props.footer), 1 /* TEXT */)
                        ])
                    ]))
                    : createCommentVNode("v-if", true)
            ]));
        };
    }
});

script$s.__file = "src/components/Card/Card.vue";

const _hoisted_1$d = ["id", "data-bs-interval"];
const _hoisted_2$a = { class: "carousel-inner" };
const _hoisted_3$5 = ["data-bs-interval"];
const _hoisted_4$2 = ["src"];
const _hoisted_5$2 = {
    key: 0,
    class: "carousel-caption d-none d-md-block"
};
const _hoisted_6$1 = { key: 0 };
const _hoisted_7$1 = { key: 1 };
const _hoisted_8 = { key: 0 };
const _hoisted_9 = ["data-bs-target"];
const _hoisted_10 = /*#__PURE__*/ createElementVNode("span", { class: "carousel-control-prev-icon" }, null, -1 /* HOISTED */);
const _hoisted_11 = [
    _hoisted_10
];
const _hoisted_12 = ["data-bs-target"];
const _hoisted_13 = /*#__PURE__*/ createElementVNode("span", { class: "carousel-control-next-icon" }, null, -1 /* HOISTED */);
const _hoisted_14 = [
    _hoisted_13
];
const _hoisted_15 = {
    key: 1,
    class: "carousel-indicators"
};
const _hoisted_16 = ["data-bs-target", "data-bs-slide-to"];
const carouselEvents = ['slid', 'slide'];
var script$r = /*#__PURE__*/ defineComponent({
    __name: 'Carousel',
    props: Object.assign(Object.assign({ 
        /**
         * Use dark mode for the controls
         */
        dark: {
            type: Boolean,
            default: false,
        }, 
        /**
         * Use a fade transition for the slides
         */
        fade: {
            type: Boolean,
            default: false,
        }, 
        /**
         * Hide the controls
         */
        hideControls: {
            type: Boolean,
            default: false,
        }, 
        /**
         * Hide the indicators
         */
        hideIndicators: {
            type: Boolean,
            default: false,
        } }, idProps), { 
        /**
         * The interval of the carousel in milliseconds
         */
        interval: {
            type: Number,
            default: 5000,
        }, 
        /**
         * The slides of the carousel
         */
        slides: {
            type: Array,
            default: () => [],
        } }),
    setup(__props, { expose, emit }) {
        const props = __props;
        const carousel = ref();
        const activeIndex = computed(() => {
            const activeSlideIndex = props.slides.findIndex((slide) => slide.active);
            return activeSlideIndex > -1 ? activeSlideIndex : 0;
        });
        useBootstrapEmits(carousel, carouselEvents, emit, 'carousel');
        const { bsInstance: bsCarousel } = useBootstrapInstance('Carousel', carousel);
        const { classes } = useClasses(computed(() => [
            props.dark ? 'carousel-dark' : null,
            props.fade ? 'carousel-fade' : null,
        ]));
        expose({ bsCarousel });
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", {
                id: _ctx.id,
                ref_key: "carousel",
                ref: carousel,
                class: normalizeClass(["carousel slide", unref(classes)]),
                "data-bs-interval": __props.interval,
                "data-bs-ride": "carousel"
            }, [
                createElementVNode("div", _hoisted_2$a, [
                    createCommentVNode("\n            @slot Displays content inside the carousel\n            @binding {array} slides The `CarouselSlide` list\n             "),
                    renderSlot(_ctx.$slots, "slides", { slides: __props.slides }, () => [
                        (openBlock(true), createElementBlock(Fragment, null, renderList(__props.slides, (slide, index) => {
                            return (openBlock(), createElementBlock("div", {
                                key: `slide-${index}`,
                                class: normalizeClass(["carousel-item", { active: index === unref(activeIndex) }]),
                                "data-bs-interval": slide.interval
                            }, [
                                createCommentVNode("\n                    @slot Displays content inside the slide\n                    @binding {int} index The index of the slide\n                    @binding {object} slide The `CarouselSlide` object\n                    "),
                                renderSlot(_ctx.$slots, "default", {
                                    index: index,
                                    slide: slide
                                }, () => [
                                    (slide.image)
                                        ? (openBlock(), createElementBlock("img", {
                                            key: 0,
                                            src: slide.image,
                                            class: "d-block w-100"
                                        }, null, 8 /* PROPS */, _hoisted_4$2))
                                        : createCommentVNode("v-if", true),
                                    createCommentVNode("\n                        @slot Display the caption of the carousel\n                        @binding {string} description The description of the slide\n                        @binding {string} title The title of the slide\n                        "),
                                    renderSlot(_ctx.$slots, "caption", {
                                        description: slide.description,
                                        title: slide.title
                                    }, () => [
                                        (slide.title || slide.description)
                                            ? (openBlock(), createElementBlock("div", _hoisted_5$2, [
                                                (slide.title)
                                                    ? (openBlock(), createElementBlock("h5", _hoisted_6$1, toDisplayString(slide.title), 1 /* TEXT */))
                                                    : createCommentVNode("v-if", true),
                                                (slide.description)
                                                    ? (openBlock(), createElementBlock("p", _hoisted_7$1, toDisplayString(slide.description), 1 /* TEXT */))
                                                    : createCommentVNode("v-if", true)
                                            ]))
                                            : createCommentVNode("v-if", true)
                                    ])
                                ])
                            ], 10 /* CLASS, PROPS */, _hoisted_3$5));
                        }), 128 /* KEYED_FRAGMENT */))
                    ])
                ]),
                (!__props.hideControls)
                    ? (openBlock(), createElementBlock("div", _hoisted_8, [
                        createCommentVNode("\n            @slot Renders a previous control button\n            @binding {Object} dataset Bootstrap data attributes required for controlling the carousel\n            "),
                        renderSlot(_ctx.$slots, "control-prev", {
                            dataset: {
                                'data-bs-target': `#${_ctx.id}`,
                                'data-bs-slide': 'prev'
                            }
                        }, () => [
                            createElementVNode("button", {
                                class: "carousel-control-prev",
                                "data-bs-target": `#${_ctx.id}`,
                                "data-bs-slide": "prev"
                            }, _hoisted_11, 8 /* PROPS */, _hoisted_9)
                        ]),
                        createCommentVNode("\n            @slot Renders a next control button\n            @binding {Object} dataset Bootstrap data attributes required for controlling the carousel\n            "),
                        renderSlot(_ctx.$slots, "control-next", {
                            dataset: {
                                'data-bs-target': `#${_ctx.id}`,
                                'data-bs-slide': 'next'
                            }
                        }, () => [
                            createElementVNode("button", {
                                class: "carousel-control-next",
                                "data-bs-target": `#${_ctx.id}`,
                                "data-bs-slide": "next"
                            }, _hoisted_14, 8 /* PROPS */, _hoisted_12)
                        ])
                    ]))
                    : createCommentVNode("v-if", true),
                (!__props.hideIndicators)
                    ? (openBlock(), createElementBlock("div", _hoisted_15, [
                        createCommentVNode("\n            @slot Renders a next control button\n            @binding {Object} dataset Bootstrap data attributes required for controlling the carousel\n            "),
                        (openBlock(true), createElementBlock(Fragment, null, renderList(__props.slides, (slide, index) => {
                            return renderSlot(_ctx.$slots, "indicator", {
                                index: index,
                                slide: slide,
                                activeIndex: unref(activeIndex),
                                dataset: {
                                    'data-bs-target': `#${_ctx.id}`,
                                    'data-bs-slide-to': index
                                }
                            }, () => [
                                (openBlock(), createElementBlock("button", {
                                    key: `slide-indicator-${index}`,
                                    class: normalizeClass({ active: index === unref(activeIndex) }),
                                    "data-bs-target": `#${_ctx.id}`,
                                    "data-bs-slide-to": index
                                }, null, 10 /* CLASS, PROPS */, _hoisted_16))
                            ]);
                        }), 256 /* UNKEYED_FRAGMENT */))
                    ]))
                    : createCommentVNode("v-if", true)
            ], 10 /* CLASS, PROPS */, _hoisted_1$d));
        };
    }
});

script$r.__file = "src/components/Carousel/Carousel.vue";

const breakpoints = ['sm', 'md', 'lg', 'xl', 'xxl'];
var useBreakpoints = (props, classTemplate) => {
    const breakpointClasses = computed(() => breakpoints
        .map(b => useStringTemplate(classTemplate, [b, unref(props[b])]).templatedString.value));
    return {
        breakpointClasses: useClasses(breakpointClasses).classes,
    };
};
const breakpointProps = (propTemplate, template = '{0}') => {
    return Object.fromEntries(breakpoints.map((b) => [
        templateString(template, b),
        propTemplate,
    ]));
};

const colProp = {
    type: [Number, String],
    default: undefined,
    validator: (c) => c === 'auto' || c === '' || (c > 0 && c <= 12),
};

const propsCol$1 = breakpointProps(colProp);
const propsOffset = breakpointProps(colProp, 'offset-{0}');
const propsOrder = breakpointProps(colProp, 'order-{0}');
var script$q = /*#__PURE__*/ defineComponent({
    __name: 'Col',
    props: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({ 
        /**
         * The amount of cols the column should span. Results in: `.col-*`
         */
        cols: colProp }, propsCol$1), { 
        /**
         * The amount of cols the column should be offset. Results in `.offset-*`
         */
        offset: colProp }), propsOffset), { 
        /**
         * The position in order of the column. Results in `.order-*`
         */
        order: colProp }), propsOrder),
    setup(__props) {
        const props = __props;
        const colProps = {
            sm: toRef(props, 'sm'),
            md: toRef(props, 'md'),
            lg: toRef(props, 'lg'),
            xl: toRef(props, 'xl'),
            xxl: toRef(props, 'xxl'),
        };
        const colClass = computed(() => {
            // Add the `.col` class by default when no cols have been specified.
            if (props.cols) {
                return useStringTemplate('col-{0}', props.cols).templatedString.value;
            }
            return 'col';
        });
        const colClasses = computed(() => {
            // When the property is empty string it would result in for example
            // `col-md-`. These classes should be transformed to `col-md`.
            return useBreakpoints(colProps, 'col-{0}-{1}')
                .breakpointClasses
                .value
                .map(c => c.replace(/\-$/, ''));
        });
        const offsetProps = {
            sm: toRef(props, 'offsetSm'),
            md: toRef(props, 'offsetMd'),
            lg: toRef(props, 'offsetLg'),
            xl: toRef(props, 'offsetXl'),
            xxl: toRef(props, 'offsetXxl'),
        };
        const offsetClass = computed(() => useStringTemplate('offset-{0}', props.offset).templatedString.value);
        const offsetClasses = useBreakpoints(offsetProps, 'offset-{0}-{1}').breakpointClasses;
        const orderProps = {
            sm: toRef(props, 'orderSm'),
            md: toRef(props, 'orderMd'),
            lg: toRef(props, 'orderLg'),
            xl: toRef(props, 'orderXl'),
            xxl: toRef(props, 'orderXxl'),
        };
        const orderClass = computed(() => useStringTemplate('order-{0}', props.order).templatedString.value);
        const orderClasses = useBreakpoints(orderProps, 'order-{0}-{1}').breakpointClasses;
        const { classes } = useClasses(computed(() => [
            colClass.value,
            ...colClasses.value,
            offsetClass.value,
            ...offsetClasses.value,
            orderClass.value,
            ...orderClasses.value,
        ]));
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", {
                class: normalizeClass(unref(classes))
            }, [
                createCommentVNode(" @slot Displays content inside the col "),
                renderSlot(_ctx.$slots, "default")
            ], 2 /* CLASS */));
        };
    }
});

script$q.__file = "src/components/Col/Col.vue";

const _hoisted_1$c = ["data-bs-target"];
const _hoisted_2$9 = ["id", "data-bs-parent"];
const collapseEvents = ['show', 'shown', 'hide', 'hidden'];
var script$p = /*#__PURE__*/ defineComponent({
    __name: 'Collapse',
    props: Object.assign(Object.assign({}, idProps), { 
        /**
         * The selector of the parent element
         * *This should be a valid query selector*
         */
        parentSelector: {
            type: String,
            default: null,
        }, 
        /**
         * Whether the collapse is visible
         */
        visible: {
            type: Boolean,
            default: false,
        } }),
    setup(__props, { expose, emit }) {
        const props = __props;
        const collapse = ref();
        useBootstrapEmits(collapse, collapseEvents, emit, 'collapse');
        const { bsInstance: bsCollapse } = useBootstrapInstance('Collapse', collapse, { toggle: props.visible });
        expose({ bsCollapse });
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock(Fragment, null, [
                createCommentVNode("\n    @slot Displays the toggle for the collapse\n    @binding {string} id The id of the target collapse\n    "),
                renderSlot(_ctx.$slots, "toggle", { id: _ctx.id }, () => [
                    createElementVNode("div", mergeProps({
                        class: "collapse-toggle",
                        "data-bs-toggle": "collapse",
                        "data-bs-target": `#${_ctx.id}`
                    }, _ctx.$attrs), [
                        createCommentVNode("\n            @slot Displays the content for the toggle\n            @binding {string} id The id of the target collapse\n            "),
                        renderSlot(_ctx.$slots, "toggleContent", { id: _ctx.id })
                    ], 16 /* FULL_PROPS */, _hoisted_1$c)
                ]),
                createElementVNode("div", {
                    id: _ctx.id,
                    ref_key: "collapse",
                    ref: collapse,
                    class: "collapse",
                    "data-bs-parent": __props.parentSelector
                }, [
                    createCommentVNode("\n        @slot Displays the content of the collapse\n        @binding {string} id The id of the collapse\n        "),
                    renderSlot(_ctx.$slots, "default", { id: _ctx.id })
                ], 8 /* PROPS */, _hoisted_2$9)
            ], 64 /* STABLE_FRAGMENT */));
        };
    }
});

script$p.__file = "src/components/Collapse/Collapse.vue";

const _hoisted_1$b = ["id"];
const _hoisted_2$8 = { class: "modal-content" };
const _hoisted_3$4 = {
    key: 0,
    class: "modal-title"
};
const _hoisted_4$1 = {
    key: 1,
    class: "btn-close",
    "data-bs-dismiss": "modal",
    type: "button"
};
const _hoisted_5$1 = {
    key: 2,
    class: "modal-footer"
};
const modalEvents = ['show', 'shown', 'hide', 'hidden', 'hidePrevented'];
var script$o = /*#__PURE__*/ defineComponent({
    __name: 'Modal',
    props: Object.assign(Object.assign(Object.assign(Object.assign({ 
        /**
         * The body text of the modal
         */
        body: {
            type: String,
            default: undefined,
        }, 
        /**
         * The classes that will be forwarded to the header
         */
        headerClass: {
            type: [String, Array, Object],
            default: undefined,
        }, 
        /**
         * Defines if the close button should be hidden
         */
        hideCloseBtn: {
            type: Boolean,
            default: false,
        } }, idProps), { 
        /**
         * Defines if the modal should be vertically centered
         */
        modalCentered: {
            type: Boolean,
            default: false,
        }, 
        /**
         * Defines if the modal should scrollable
         */
        modalScrollable: {
            type: Boolean,
            default: false,
        }, 
        /**
         * Defines if the `modal-body` class should be omitted
         */
        noBody: {
            type: Boolean,
            default: false,
        } }), sizeProps), { 
        /**
         * The title text of the modal
         */
        title: {
            type: String,
            default: undefined,
        } }),
    setup(__props, { expose, emit }) {
        const props = __props;
        const modal = ref();
        useBootstrapEmits(modal, modalEvents, emit, 'modal');
        const { bsInstance: bsModal } = useBootstrapInstance('Modal', modal);
        const { classes } = useClasses(computed(() => [
            props.modalCentered ? 'modal-dialog-centered' : null,
            props.modalScrollable ? 'modal-dialog-scrollable' : null,
            props.size ? useSize(props.size, 'modal-{0}').sizeClass.value : null,
        ]));
        onBeforeUnmount(() => {
            if (bsModal.value) {
                bsModal.value.hide();
            }
        });
        expose({ bsModal });
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", {
                id: _ctx.id,
                ref_key: "modal",
                ref: modal,
                class: "modal"
            }, [
                createElementVNode("div", {
                    class: normalizeClass(["modal-dialog", unref(classes)])
                }, [
                    createElementVNode("div", _hoisted_2$8, [
                        (!!_ctx.$slots.header || !!_ctx.$slots.title || !!__props.title || !__props.hideCloseBtn)
                            ? (openBlock(), createElementBlock("div", {
                                key: 0,
                                class: normalizeClass(['modal-header', __props.headerClass])
                            }, [
                                createCommentVNode(" @slot Displays the header of the modal "),
                                renderSlot(_ctx.$slots, "header", {}, () => [
                                    (!!_ctx.$slots.title || !!__props.title)
                                        ? (openBlock(), createElementBlock("h5", _hoisted_3$4, [
                                            createCommentVNode(" @slot Displays the header title of the modal "),
                                            renderSlot(_ctx.$slots, "title", {}, () => [
                                                createTextVNode(toDisplayString(__props.title), 1 /* TEXT */)
                                            ])
                                        ]))
                                        : createCommentVNode("v-if", true),
                                    (!__props.hideCloseBtn)
                                        ? (openBlock(), createElementBlock("button", _hoisted_4$1))
                                        : createCommentVNode("v-if", true)
                                ])
                            ], 2 /* CLASS */))
                            : createCommentVNode("v-if", true),
                        (_ctx.$slots.default || __props.body)
                            ? (openBlock(), createElementBlock("div", {
                                key: 1,
                                class: normalizeClass({ 'modal-body': !__props.noBody })
                            }, [
                                createCommentVNode(" @slot Displays the body of the modal "),
                                renderSlot(_ctx.$slots, "default", {}, () => [
                                    createTextVNode(toDisplayString(__props.body), 1 /* TEXT */)
                                ])
                            ], 2 /* CLASS */))
                            : createCommentVNode("v-if", true),
                        (_ctx.$slots.footer)
                            ? (openBlock(), createElementBlock("div", _hoisted_5$1, [
                                createCommentVNode(" @slot Displays the footer of the modal "),
                                renderSlot(_ctx.$slots, "footer")
                            ]))
                            : createCommentVNode("v-if", true)
                    ])
                ], 2 /* CLASS */)
            ], 8 /* PROPS */, _hoisted_1$b));
        };
    }
});

script$o.__file = "src/components/Modal/Modal.vue";

var script$n = /*#__PURE__*/ defineComponent({
    __name: 'Confirm',
    props: {
        /**
         * The body of the confirm modal
         */
        body: {
            type: String,
            default: 'Are you sure?',
        },
        /**
         * Changes the cancel button to an outline variant
         */
        cancelOutline: {
            type: Boolean,
            default: false,
        },
        /**
         * The text of the cancel button
         */
        cancelText: {
            type: String,
            default: 'No',
        },
        /**
         * The variant of the cancel button
         */
        cancelVariant: variantProp('light'),
        /**
         * The text of the ok button
         */
        okText: {
            type: String,
            default: 'Yes',
        },
        /**
         * The variant of the ok button
         */
        okVariant: variantProp('primary'),
        /**
         * The title of the confirm modal
         */
        title: {
            type: String,
            default: 'Confirmation',
        },
    },
    emits: ["cancelled", "confirmed"],
    setup(__props, { expose, emit }) {
        const cancel = () => {
            emit('cancelled');
            hide();
        };
        const ok = () => {
            emit('confirmed');
            hide();
        };
        const modal = ref();
        const hide = () => { var _a; return (_a = modal.value.bsModal) === null || _a === void 0 ? void 0 : _a.hide(); };
        const show = () => { var _a; return (_a = modal.value.bsModal) === null || _a === void 0 ? void 0 : _a.show(); };
        const toggle = () => { var _a; return (_a = modal.value.bsModal) === null || _a === void 0 ? void 0 : _a.toggle(); };
        expose({ hide, show, toggle });
        return (_ctx, _cache) => {
            return (openBlock(), createBlock(unref(script$o), {
                ref_key: "modal",
                ref: modal,
                title: __props.title
            }, {
                footer: withCtx(() => [
                    createCommentVNode(" @slot Displays content inside the cancel button "),
                    renderSlot(_ctx.$slots, "buttonCancel", {}, () => [
                        createVNode(unref(script$x), {
                            class: "button-cancel",
                            outline: __props.cancelOutline,
                            variant: __props.cancelVariant,
                            onClick: cancel
                        }, {
                            default: withCtx(() => [
                                createTextVNode(toDisplayString(__props.cancelText), 1 /* TEXT */)
                            ]),
                            _: 1 /* STABLE */
                        }, 8 /* PROPS */, ["outline", "variant"])
                    ]),
                    createCommentVNode(" @slot Displays content inside the ok button "),
                    renderSlot(_ctx.$slots, "buttonOk", {}, () => [
                        createVNode(unref(script$x), {
                            class: "button-ok",
                            variant: __props.okVariant,
                            onClick: ok
                        }, {
                            default: withCtx(() => [
                                createTextVNode(toDisplayString(__props.okText), 1 /* TEXT */)
                            ]),
                            _: 1 /* STABLE */
                        }, 8 /* PROPS */, ["variant"])
                    ])
                ]),
                default: withCtx(() => [
                    renderSlot(_ctx.$slots, "default", {}, () => [
                        createTextVNode(toDisplayString(__props.body), 1 /* TEXT */)
                    ])
                ]),
                _: 3 /* FORWARDED */
            }, 8 /* PROPS */, ["title"]));
        };
    }
});

script$n.__file = "src/components/Confirm/Confirm.vue";

var script$m = /*#__PURE__*/ defineComponent({
    __name: 'Container',
    props: {
        /**
         * Uses the `container-fluid` class
         */
        fluid: {
            type: Boolean,
            default: false,
        },
    },
    setup(__props) {
        const props = __props;
        const { classes } = useClasses(computed(() => [
            `container${props.fluid ? '-fluid' : ''}`,
        ]));
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", {
                class: normalizeClass(unref(classes))
            }, [
                createCommentVNode(" @slot Displays content inside the container "),
                renderSlot(_ctx.$slots, "default")
            ], 2 /* CLASS */));
        };
    }
});

script$m.__file = "src/components/Container/Container.vue";

const dropdownItemsProps = {
    items: {
        type: Array,
        default: () => [],
    },
};

const dropdownItemProps = {
    /**
     * The classes that will be forwarded to the link
     */
    itemClass: {
        type: [String, Array, Object],
        default: undefined,
    },
};

var script$l = /*#__PURE__*/ defineComponent({
    __name: 'DropdownMenuItem',
    props: Object.assign(Object.assign({ 
        /**
         * Adds the `active` class
         */
        active: {
            type: Boolean,
            default: false,
        }, 
        /**
         * Displays a divider
         */
        divider: {
            type: Boolean,
            default: false,
        } }, dropdownItemProps), { 
        /**
         * Displays label as header
         */
        header: {
            type: Boolean,
            default: false,
        }, href: {
            type: String,
            default: '#',
        }, is: {
            type: String,
            default: undefined,
        }, 
        /**
         * The label to display
         */
        label: {
            type: String,
            default: undefined,
        }, to: {
            type: [Object, String],
            default: undefined,
        } }),
    setup(__props) {
        const props = __props;
        const is = computed(() => {
            if (props.is) {
                return props.is;
            }
            if (props.to) {
                return 'RouterLink';
            }
            return 'a';
        });
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("li", null, [
                (__props.divider)
                    ? (openBlock(), createElementBlock("hr", {
                        key: 0,
                        class: normalizeClass(["dropdown-divider", _ctx.itemClass])
                    }, null, 2 /* CLASS */))
                    : (__props.header)
                        ? (openBlock(), createElementBlock("h6", {
                            key: 1,
                            class: normalizeClass(["dropdown-header", _ctx.itemClass])
                        }, [
                            createCommentVNode(" @slot Displays content inside the dropdown menu item. "),
                            renderSlot(_ctx.$slots, "default", {}, () => [
                                createTextVNode(toDisplayString(__props.label), 1 /* TEXT */)
                            ])
                        ], 2 /* CLASS */))
                        : (openBlock(), createBlock(resolveDynamicComponent(unref(is)), {
                            key: 2,
                            class: normalizeClass(["dropdown-item", [{ active: __props.active }, _ctx.itemClass]]),
                            href: __props.href,
                            to: __props.to,
                            onClick: _cache[0] || (_cache[0] = withModifiers(() => { }, ["prevent"]))
                        }, {
                            default: withCtx(() => [
                                renderSlot(_ctx.$slots, "default", {}, () => [
                                    createTextVNode(toDisplayString(__props.label), 1 /* TEXT */)
                                ])
                            ]),
                            _: 3 /* FORWARDED */
                        }, 8 /* PROPS */, ["class", "href", "to"]))
            ]));
        };
    }
});

script$l.__file = "src/components/DropdownMenuItem/DropdownMenuItem.vue";

const _hoisted_1$a = { class: "dropdown-menu" };
var script$k = /*#__PURE__*/ defineComponent({
    __name: 'DropdownMenu',
    props: Object.assign(Object.assign({}, dropdownItemProps), dropdownItemsProps),
    emits: [
        /**
         * Fired when an item is clicked
         * @param {Item} item The item that was clicked
         */
        'click:item',
    ],
    setup(__props, { emit }) {
        const clickItem = (item) => emit('click:item', item);
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("ul", _hoisted_1$a, [
                createCommentVNode(" @slot Prepends the dropdown menu "),
                renderSlot(_ctx.$slots, "prepend"),
                createCommentVNode("\n        @slot Displays content inside the dropdown menu\n        @binding {array} items The `Item` list\n        @binding {function} click-item The function to call when an item is clicked\n        "),
                renderSlot(_ctx.$slots, "items", {
                    clickItem: clickItem,
                    items: _ctx.items
                }, () => [
                    (openBlock(true), createElementBlock(Fragment, null, renderList(_ctx.items, (item, index) => {
                        return (openBlock(), createElementBlock(Fragment, {
                            key: `item-${index.toString()}`
                        }, [
                            createCommentVNode("\n                @slot Displays the dropdown menu item\n                @binding {object} item The `Item` object\n                @binding {function} click-item The function to call when an item is clicked\n                "),
                            renderSlot(_ctx.$slots, "item", {
                                clickItem: clickItem,
                                item: item
                            }, () => [
                                createVNode(unref(script$l), mergeProps(item, {
                                    "item-class": _ctx.itemClass,
                                    onClick: ($event) => (clickItem(item))
                                }), null, 16 /* FULL_PROPS */, ["item-class", "onClick"])
                            ])
                        ], 64 /* STABLE_FRAGMENT */));
                    }), 128 /* KEYED_FRAGMENT */))
                ]),
                createCommentVNode(" @slot Appends the dropdown menu "),
                renderSlot(_ctx.$slots, "append")
            ]));
        };
    }
});

script$k.__file = "src/components/DropdownMenu/DropdownMenu.vue";

const dropdownProps = Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, dropdownItemsProps), { menuClass: {
        type: String,
        default: undefined,
    } }), sizeProps), { 
    /**
     * The classes that will be forwarded to the toggle
     */
    toggleClass: {
        type: [String, Array, Object],
        default: undefined,
    } }), variantProps);

const dropdownEvents = ['show', 'shown', 'hide', 'hidden'];
var script$j = /*#__PURE__*/ defineComponent({
    __name: 'Dropdown',
    props: Object.assign(Object.assign({}, dropdownItemProps), dropdownProps),
    setup(__props, { expose, emit }) {
        const dropdown = ref();
        useBootstrapEmits(dropdown, dropdownEvents, emit, 'dropdown');
        const { bsInstance: bsDropdown } = useBootstrapInstance('Dropdown', dropdown);
        expose({ bsDropdown });
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", {
                ref_key: "dropdown",
                ref: dropdown,
                class: "dropdown"
            }, [
                createCommentVNode(" @slot Displays the dropdown toggle "),
                renderSlot(_ctx.$slots, "dropdownToggle", {}, () => [
                    createVNode(unref(script$x), {
                        class: normalizeClass(["dropdown-toggle", _ctx.toggleClass]),
                        "data-bs-toggle": "dropdown",
                        size: _ctx.size,
                        variant: _ctx.variant
                    }, {
                        default: withCtx(() => [
                            createCommentVNode(" @slot Displays content inside the dropdown toggle "),
                            renderSlot(_ctx.$slots, "default", {}, () => [
                                createTextVNode(" Select ")
                            ])
                        ]),
                        _: 3 /* FORWARDED */
                    }, 8 /* PROPS */, ["class", "size", "variant"])
                ]),
                createCommentVNode("\n        @slot Displays the dropdown menu\n        @binding {array} items The `Item` list\n        "),
                renderSlot(_ctx.$slots, "dropdownMenu", mergeProps({ 'onClick:item': _ctx.$attrs['onClick:item'] }, { items: _ctx.items }), () => [
                    createVNode(unref(script$k), mergeProps({
                        items: _ctx.items,
                        class: _ctx.menuClass,
                        "item-class": _ctx.itemClass
                    }, { 'onClick:item': _ctx.$attrs['onClick:item'] }), {
                        prepend: withCtx((slotScope) => [
                            createCommentVNode(" @slot *Forwarded to child* "),
                            renderSlot(_ctx.$slots, "prepend", normalizeProps(guardReactiveProps(slotScope)))
                        ]),
                        items: withCtx((slotScope) => [
                            createCommentVNode(" @slot *Forwarded to child* "),
                            renderSlot(_ctx.$slots, "items", normalizeProps(guardReactiveProps(slotScope)))
                        ]),
                        item: withCtx((slotScope) => [
                            createCommentVNode(" @slot *Forwarded to child* "),
                            renderSlot(_ctx.$slots, "item", normalizeProps(guardReactiveProps(slotScope)))
                        ]),
                        append: withCtx((slotScope) => [
                            createCommentVNode(" @slot *Forwarded to child* "),
                            renderSlot(_ctx.$slots, "append", normalizeProps(guardReactiveProps(slotScope)))
                        ]),
                        _: 3 /* FORWARDED */
                    }, 16 /* FULL_PROPS */, ["items", "class", "item-class"])
                ])
            ], 512 /* NEED_PATCH */));
        };
    }
});

script$j.__file = "src/components/Dropdown/Dropdown.vue";

const types$1 = ['checkbox', 'radio'];
const typeProp = {
    type: String,
    default: 'checkbox',
    validator: (t) => types$1.includes(t),
};

const _hoisted_1$9 = ["id", "disabled", "name", "type", "value"];
const _hoisted_2$7 = ["for"];
var script$i = /*#__PURE__*/ defineComponent({
    __name: 'FormCheck',
    props: Object.assign(Object.assign(Object.assign({}, disabledProps), idProps), { 
        /**
         * Adds the `form-check-inline` class
         */
        inline: {
            type: Boolean,
            default: false,
        }, 
        /**
         * The classes that will be forwarded to the input
         */
        inputClass: {
            type: [String, Array, Object],
            default: undefined,
        }, 
        /**
         * The label to display
         */
        label: {
            type: String,
            default: undefined,
        }, 
        /**
         * The model value
         */
        modelValue: {
            type: [Boolean, String, Number],
            default: false,
        }, 
        /**
         * The name of the input
         */
        name: {
            type: String,
            default: undefined,
        }, 
        /**
         * Display the check as a switch by adding the `form-switch` class
         */
        switch: {
            type: Boolean,
            default: false,
        }, 
        /**
         * The type of the input
         * @values 'checkbox'|'radio'
         */
        type: typeProp, 
        /**
         * The value of the input
         */
        value: {
            type: [String, Number],
            default: undefined,
        } }),
    emits: [
        /**
         * Fired when the model value is updated
         * @param {any} value The new value
         */
        'update:modelValue',
    ],
    setup(__props, { emit }) {
        const props = __props;
        const checked = computed({
            get: () => props.modelValue,
            set(v) {
                let value = v;
                if (props.value) {
                    value = v ? props.value : undefined;
                }
                emit('update:modelValue', value);
            },
        });
        // Required to prevent the use of a reserved word.
        const isSwitch = computed(() => props.switch);
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", {
                class: normalizeClass(["form-check", { 'form-switch': unref(isSwitch), 'form-check-inline': __props.inline }])
            }, [
                withDirectives(createElementVNode("input", {
                    id: _ctx.id,
                    "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => (isRef(checked) ? (checked).value = $event : null)),
                    class: normalizeClass(["form-check-input", __props.inputClass]),
                    disabled: _ctx.disabled,
                    name: __props.name,
                    type: __props.type,
                    value: __props.value
                }, null, 10 /* CLASS, PROPS */, _hoisted_1$9), [
                    [vModelDynamic, unref(checked)]
                ]),
                (_ctx.$slots.default || __props.label)
                    ? (openBlock(), createElementBlock("label", {
                        key: 0,
                        class: "form-check-label",
                        for: _ctx.id
                    }, [
                        createCommentVNode(" @slot Displays content inside the label "),
                        renderSlot(_ctx.$slots, "default", {}, () => [
                            createTextVNode(toDisplayString(__props.label), 1 /* TEXT */)
                        ])
                    ], 8 /* PROPS */, _hoisted_2$7))
                    : createCommentVNode("v-if", true)
            ], 2 /* CLASS */));
        };
    }
});

script$i.__file = "src/components/FormCheck/FormCheck.vue";

var script$h = /*#__PURE__*/ defineComponent({
    __name: 'FormCheckGroup',
    props: Object.assign(Object.assign({}, disabledProps), { 
        /**
         * Display the checks as a switch by adding the `form-switch` class
         */
        switch: {
            type: Boolean,
            default: false,
        }, 
        /**
         * The items to display in the group
         */
        items: {
            type: Array,
            required: true,
        }, 
        /**
         * The type of the input
         * @values 'checkbox'|'radio'
         */
        type: typeProp, 
        // Put `modelValue` after `type` so it will be available in `default`.
        /**
         * The model value
         */
        modelValue: {
            type: [Array, String, Number, undefined],
            default: (props) => props.type === 'checkbox' ? [] : undefined,
        } }),
    emits: [
        /**
         * Fired when the model value is updated
         * @param {any} value The new value
         */
        'update:modelValue',
    ],
    setup(__props, { emit }) {
        const props = __props;
        const name = props.type === 'checkbox' ? undefined : idProps.id.default();
        // Required to prevent the use of reserved word `switch` in template.
        const isSwitch = computed(() => props.switch);
        const value = computed({
            get: () => props.modelValue,
            set: (v) => emit('update:modelValue', v),
        });
        const getValue = (i) => props.type === 'checkbox' ? !!value.value[i] : value.value;
        const setValue = (v, i) => {
            if (props.type === 'checkbox') {
                const clone = [...value.value];
                clone[i] = v;
                value.value = clone;
            }
            else {
                value.value = v;
            }
        };
        return (_ctx, _cache) => {
            return (openBlock(true), createElementBlock(Fragment, null, renderList(__props.items, (item, index) => {
                return (openBlock(), createBlock(unref(script$i), {
                    key: item.value,
                    disabled: _ctx.disabled,
                    label: item.label || item.value,
                    "model-value": getValue(index),
                    name: unref(name),
                    type: __props.type,
                    switch: unref(isSwitch),
                    value: item.value,
                    "onUpdate:modelValue": ($event) => (setValue($event, index))
                }, null, 8 /* PROPS */, ["disabled", "label", "model-value", "name", "type", "switch", "value", "onUpdate:modelValue"]));
            }), 128 /* KEYED_FRAGMENT */));
        };
    }
});

script$h.__file = "src/components/FormCheckGroup/FormCheckGroup.vue";

const types = [
    'button',
    'checkbox',
    'color',
    'date',
    'datetime-local',
    'email',
    'file',
    'hidden',
    'image',
    'month',
    'number',
    'password',
    'radio',
    'range',
    'reset',
    'search',
    'submit',
    'tel',
    'text',
    'time',
    'url',
    'week',
];
const formControlProps = Object.assign(Object.assign(Object.assign(Object.assign({ autofocus: {
        type: Boolean,
        default: false,
    } }, disabledProps), { modelValue: {
        type: String,
        default: '',
    }, placeholder: {
        type: String,
        default: '',
    }, plainText: {
        type: Boolean,
        default: false,
    }, readonly: {
        type: Boolean,
        default: false,
    }, required: {
        type: Boolean,
        default: false,
    } }), sizeProps), { type: {
        type: String,
        default: 'text',
        validator: (v) => types.includes(v),
    } });

const _hoisted_1$8 = ["autofocus", "disabled", "placeholder", "readonly", "type", "value"];
var script$g = /*#__PURE__*/ defineComponent({
    __name: 'FormControl',
    props: formControlProps,
    emits: [
        /**
         * Fired when the model value is updated
         * @param {any} value The new value
         */
        'update:modelValue',
    ],
    setup(__props, { expose, emit }) {
        const props = __props;
        const input = ref();
        const { classes } = useClasses(computed(() => [
            useDisabled(props.disabled).disabledClass.value,
            props.plainText ? 'form-control-plaintext' : '',
            props.readonly ? 'readonly' : '',
            useSize(props.size, 'form-control-{0}').sizeClass.value,
        ]));
        expose({ input });
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("input", {
                ref_key: "input",
                ref: input,
                autofocus: _ctx.autofocus,
                class: normalizeClass(["form-control", unref(classes)]),
                disabled: _ctx.disabled,
                placeholder: _ctx.placeholder,
                readonly: _ctx.readonly,
                type: _ctx.type,
                value: _ctx.modelValue,
                onInput: _cache[0] || (_cache[0] = ($event) => (emit('update:modelValue', $event.target.value)))
            }, null, 42 /* CLASS, PROPS, HYDRATE_EVENTS */, _hoisted_1$8));
        };
    }
});

script$g.__file = "src/components/FormControl/FormControl.vue";

var useFormSelect = (props) => useClasses(computed(() => [
    useDisabled(unref(props).disabled).disabledClass.value,
    useSize(unref(props).size, 'form-select-{0}').sizeClass.value,
]));
const formSelectProps = Object.assign(Object.assign(Object.assign({}, disabledProps), { items: {
        type: Array,
        default: () => [],
    } }), sizeProps);

var extractKeysFrom = (keys, from) => computed(() => Object.fromEntries(keys.map(k => [k, from[k]])));

const { disabled: disabledProp, size: sizeProp } = formSelectProps;
var script$f = /*#__PURE__*/ defineComponent({
    __name: 'FormDropdown',
    props: Object.assign(Object.assign({}, dropdownProps), { 
        /**
         * Disables the component
         */
        disabled: disabledProp, 
        /**
         * The key that is used to get the label from a given item
         */
        labelKey: {
            type: String,
            default: 'label',
        }, 
        /**
         * The classes that will be forwarded to the menu
         */
        menuClass: {
            type: String,
            default: 'w-100',
        }, 
        /**
         * The model value
         */
        modelValue: {
            type: Object,
            default: undefined,
        }, 
        /**
         * The placeholder of the dropdown
         */
        placeholder: {
            type: String,
            default: 'Select',
        }, size: sizeProp, 
        /**
         * The classes that will be forwarded to the toggle
         */
        toggleClass: {
            type: String,
            default: undefined,
        } }),
    emits: [
        /**
         * Fired when the model value is updated
         * @param {any} value The new value
         */
        'update:modelValue',
    ],
    setup(__props, { emit }) {
        const props = __props;
        const propsDropdown = extractKeysFrom(Object.keys(dropdownProps), props);
        const label = computed(() => {
            if (!props.modelValue) {
                return props.placeholder;
            }
            return props.modelValue[props.labelKey];
        });
        const { classes } = useClasses(computed(() => [
            ...useFormSelect(props).classes.value,
            props.toggleClass,
        ]));
        return (_ctx, _cache) => {
            return (openBlock(), createBlock(unref(script$j), mergeProps({ class: "form-dropdown" }, unref(propsDropdown), {
                "onClick:item": _cache[0] || (_cache[0] = ($event) => (emit('update:modelValue', $event)))
            }), {
                dropdownToggle: withCtx(() => [
                    createCommentVNode(" @slot Displays the dropdown toggle "),
                    renderSlot(_ctx.$slots, "dropdownToggle", {}, () => [
                        createElementVNode("div", {
                            class: normalizeClass(["form-select", unref(classes)]),
                            "data-bs-toggle": "dropdown"
                        }, [
                            createCommentVNode(" @slot Displays the dropdown toggle label "),
                            createCommentVNode(" @binding {{label: string, modelValue: Object}} dataset Bootstrap data attributes required for controlling the carousel "),
                            renderSlot(_ctx.$slots, "dropdownToggleLabel", normalizeProps(guardReactiveProps({ label: unref(label), modelValue: __props.modelValue })), () => [
                                createTextVNode(toDisplayString(unref(label)), 1 /* TEXT */)
                            ])
                        ], 2 /* CLASS */)
                    ])
                ]),
                prepend: withCtx(() => [
                    createCommentVNode(" @slot Displays content when there are no options "),
                    (_ctx.items.length === 0)
                        ? renderSlot(_ctx.$slots, "noOptions", { key: 0 }, () => [
                            createVNode(unref(script$l), {
                                class: "pe-none",
                                label: "No options"
                            })
                        ])
                        : createCommentVNode("v-if", true),
                    createCommentVNode(" @slot Prepends the dropdown options "),
                    renderSlot(_ctx.$slots, "prepend")
                ]),
                items: withCtx((slotScope) => [
                    createCommentVNode(" @slot *Forwarded to child* "),
                    renderSlot(_ctx.$slots, "items", normalizeProps(guardReactiveProps(slotScope)))
                ]),
                item: withCtx((slotScope) => [
                    createCommentVNode(" @slot *Forwarded to child* "),
                    renderSlot(_ctx.$slots, "item", normalizeProps(guardReactiveProps(slotScope)))
                ]),
                append: withCtx((slotScope) => [
                    createCommentVNode(" @slot *Forwarded to child* "),
                    renderSlot(_ctx.$slots, "append", normalizeProps(guardReactiveProps(slotScope)))
                ]),
                _: 3 /* FORWARDED */
            }, 16 /* FULL_PROPS */));
        };
    }
});

script$f.__file = "src/components/FormDropdown/FormDropdown.vue";

var script$e = /*#__PURE__*/ defineComponent({
    __name: 'FormDropdownSearch',
    props: Object.assign(Object.assign({}, formControlProps), { 
        /**
         * Automatically search through the items
         */
        autoSearch: {
            type: Boolean,
            default: true,
        }, 
        /**
         * The items of the dropdown menu
         */
        items: {
            type: Array,
            default: () => [],
        }, 
        /**
         * The key that is used to get the label from a given item
         */
        labelKey: {
            type: String,
            default: 'label',
        }, 
        /**
         * The model value
         */
        modelValue: {
            type: Object,
            default: undefined,
        }, 
        /**
         * The placeholder of the form input
         */
        placeholder: {
            type: String,
            default: '',
        }, 
        /**
         * The current search string
         */
        search: {
            type: String,
            default: '',
        } }),
    emits: [
        /**
         * Fired when the model value is updated
         * @param {any} value The new value
         */
        'update:modelValue',
        /**
         * Fired when the search value is updated
         * @param {string} search The new search value
         */
        'update:search',
    ],
    setup(__props, { expose, emit }) {
        const props = __props;
        const propsFormControl = extractKeysFrom(Object.keys(formControlProps)
            .filter(k => !['modelValue', 'placeholder'].includes(k)), props);
        const propsDropdown = extractKeysFrom(Object.keys(dropdownProps)
            .filter(k => !['items', 'labelKey'].includes(k)), props);
        const filteredItems = computed(() => {
            if (searchValue.value === '' || !props.autoSearch) {
                return props.items;
            }
            return props.items
                .filter(i => i.label
                .toLowerCase()
                .includes(searchValue.value.toLocaleLowerCase()));
        });
        const formControl = ref();
        const formDropdown = ref();
        const { bsInstance: bsDropdown } = useBootstrapInstance('Dropdown', formControl);
        const modelValue = computed({
            get: () => props.modelValue,
            set: v => emit('update:modelValue', v),
        });
        const modelValueLabel = computed(() => { var _a; return (_a = modelValue.value) === null || _a === void 0 ? void 0 : _a[props.labelKey]; });
        const searchValue = ref(modelValueLabel.value || props.search);
        /**
         * Is used to display a temporary value in the input while still emitting an
         * empty `search` to the parent. This will for example happen when this
         * component has a `modelValue` and the user focuses on the input. The parent
         * should receive an empty `search` so it can display more options than options
         * that match the `labelKey` of the `modelValue`. It acts af is there is no
         * `search` while still displaying the `modelValue`.
         */
        const searchValueCached = ref('');
        const searchValueDisplayed = computed({
            get: () => searchValueCached.value !== ''
                ? ''
                : searchValue.value,
            set: s => {
                searchValue.value = s;
                emit('update:search', s);
            },
        });
        onMounted(() => {
            // Get the dropdown toggle element manually because it is possible to
            // override it with the `dropdownToggle` slot.
            const dropdownToggle = formDropdown.value
                .$el
                .querySelector('[data-bs-toggle="dropdown"]');
            dropdownToggle === null || dropdownToggle === void 0 ? void 0 : dropdownToggle.addEventListener('shown.bs.dropdown', () => {
                var _a;
                (_a = dropdownToggle.input) === null || _a === void 0 ? void 0 : _a.focus();
                if (modelValueLabel.value) {
                    searchValueCached.value = modelValueLabel.value;
                }
                searchValue.value = '';
                if (props.search !== '') {
                    emit('update:search', '');
                }
            });
            dropdownToggle === null || dropdownToggle === void 0 ? void 0 : dropdownToggle.addEventListener('hidden.bs.dropdown', () => {
                var _a;
                (_a = dropdownToggle.input) === null || _a === void 0 ? void 0 : _a.blur();
                if (!modelValue.value) {
                    searchValue.value = '';
                }
                else {
                    searchValue.value = modelValueLabel.value;
                }
                searchValueCached.value = '';
            });
        });
        const showMenu = () => {
            if (bsDropdown.value) {
                // TODO: BS calls `toggle` once a user clicks on any
                // `data-bs-toggle="dropdown"`. This event is being fired after the
                // `focus` event, thus will result in hiding the menu after we call
                // `show`. `await nextTick()` also does not solve this problem.
                setTimeout(() => bsDropdown.value.show(), 200);
            }
        };
        watch(modelValue, newValue => {
            if (newValue) {
                searchValue.value = newValue[props.labelKey];
            }
            else {
                searchValue.value = '';
            }
        });
        watch(() => props.search, s => searchValue.value = s);
        expose({ bsDropdown, formControl });
        return (_ctx, _cache) => {
            return (openBlock(), createBlock(unref(script$f), mergeProps({
                ref_key: "formDropdown",
                ref: formDropdown,
                modelValue: unref(modelValue),
                "onUpdate:modelValue": _cache[2] || (_cache[2] = ($event) => (isRef(modelValue) ? (modelValue).value = $event : null)),
                class: "form-dropdown-search",
                items: unref(filteredItems),
                "label-key": __props.labelKey
            }, unref(propsDropdown)), {
                dropdownToggle: withCtx(() => [
                    createCommentVNode(" @slot Displays the dropdown toggle "),
                    renderSlot(_ctx.$slots, "dropdownToggle", {
                        value: unref(modelValue),
                        search: unref(searchValueDisplayed),
                        placeholder: searchValueCached.value || __props.placeholder,
                        propsFormControl: unref(propsFormControl),
                        "onUpdate:search": _cache[0] || (_cache[0] = s => searchValueDisplayed.value = s)
                    }, () => [
                        createVNode(unref(script$g), mergeProps({
                            ref_key: "formControl",
                            ref: formControl,
                            modelValue: unref(searchValueDisplayed),
                            "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => (isRef(searchValueDisplayed) ? (searchValueDisplayed).value = $event : null)),
                            class: "form-select",
                            "data-bs-toggle": "dropdown",
                            placeholder: searchValueCached.value || __props.placeholder
                        }, unref(propsFormControl), { onFocus: showMenu }), null, 16 /* FULL_PROPS */, ["modelValue", "placeholder"])
                    ])
                ]),
                noOptions: withCtx((slotScope) => [
                    createCommentVNode(" @slot *Forwarded to child* "),
                    renderSlot(_ctx.$slots, "noOptions", normalizeProps(guardReactiveProps(slotScope)))
                ]),
                prepend: withCtx((slotScope) => [
                    createCommentVNode(" @slot *Forwarded to child* "),
                    renderSlot(_ctx.$slots, "prepend", normalizeProps(guardReactiveProps(slotScope)))
                ]),
                items: withCtx((slotScope) => [
                    createCommentVNode(" @slot *Forwarded to child* "),
                    renderSlot(_ctx.$slots, "items", normalizeProps(guardReactiveProps(slotScope)))
                ]),
                item: withCtx((slotScope) => [
                    createCommentVNode(" @slot *Forwarded to child* "),
                    renderSlot(_ctx.$slots, "item", normalizeProps(guardReactiveProps(slotScope)))
                ]),
                append: withCtx((slotScope) => [
                    createCommentVNode(" @slot *Forwarded to child* "),
                    renderSlot(_ctx.$slots, "append", normalizeProps(guardReactiveProps(slotScope)))
                ]),
                _: 3 /* FORWARDED */
            }, 16 /* FULL_PROPS */, ["modelValue", "items", "label-key"]));
        };
    }
});

script$e.__file = "src/components/FormDropdownSearch/FormDropdownSearch.vue";

const _hoisted_1$7 = ["for"];
const _hoisted_2$6 = {
    key: 0,
    class: "form-text"
};
const _hoisted_3$3 = {
    key: 3,
    class: "form-text"
};
var script$d = /*#__PURE__*/ defineComponent({
    __name: 'FormGroup',
    props: Object.assign(Object.assign(Object.assign({ 
        /**
         * The description of the form group
         * *Displayed between label and input*
         */
        description: {
            type: String,
            default: undefined,
        }, 
        /**
         * The help text of the form group
         * *Displayed under input*
         */
        helpText: {
            type: String,
            default: undefined,
        } }, idProps), formControlProps), { 
        /**
         * The invalid feedback of the form group
         * *Displayed between input and helpText*
         */
        invalidFeedback: {
            type: [Array, String],
            default: () => [],
        }, 
        /**
         * The label to display
         */
        label: {
            type: String,
            default: undefined,
        }, 
        /**
         * The classes that will be forwarded to the label
         */
        labelClass: {
            type: [String, Array, Object],
            default: undefined,
        }, 
        /**
         * The valid feedback of the form group
         * *Displayed between input and helpText*
         */
        validFeedback: {
            type: [Array, String],
            default: () => [],
        } }),
    emits: [
        /**
         * Fired when the model value is updated
         * @param {any} value The new value
         */
        'update:modelValue',
    ],
    setup(__props, { emit }) {
        const props = __props;
        const propsFormControl = extractKeysFrom(Object.keys(formControlProps), props);
        const invalidFeedback = computed(() => [props.invalidFeedback].flat().filter(f => !!f));
        const isInvalid = computed(() => !!invalidFeedback.value.length);
        const validFeedback = computed(() => [props.validFeedback].flat().filter(f => !!f));
        const isValid = computed(() => !!validFeedback.value.length);
        const validityClass = computed(() => [
            isInvalid.value ? 'is-invalid' : undefined,
            isValid.value ? 'is-valid' : undefined,
        ]);
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", null, [
                (!!_ctx.$slots.label || __props.label || __props.description)
                    ? (openBlock(), createElementBlock("label", {
                        key: 0,
                        class: normalizeClass(["form-label", __props.labelClass]),
                        for: _ctx.id
                    }, [
                        createCommentVNode("\n            @slot Displays content inside the label\n            @binding {string} label The text of the label\n            "),
                        renderSlot(_ctx.$slots, "label", { label: __props.label }, () => [
                            createTextVNode(toDisplayString(__props.label), 1 /* TEXT */)
                        ]),
                        (!!__props.description)
                            ? (openBlock(), createElementBlock("div", _hoisted_2$6, toDisplayString(__props.description), 1 /* TEXT */))
                            : createCommentVNode("v-if", true)
                    ], 10 /* CLASS, PROPS */, _hoisted_1$7))
                    : createCommentVNode("v-if", true),
                createCommentVNode("\n        @slot Displays the input\n        @binding {boolean} is-invalid Describes if the input is invalid\n        @binding {boolean} is-valid Describes if the input is valid\n        "),
                renderSlot(_ctx.$slots, "default", {
                    isInvalid: unref(isInvalid),
                    isValid: unref(isValid)
                }, () => [
                    createVNode(unref(script$g), mergeProps(unref(propsFormControl), {
                        id: _ctx.id,
                        class: unref(validityClass),
                        "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => (emit('update:modelValue', $event)))
                    }), null, 16 /* FULL_PROPS */, ["id", "class"])
                ]),
                (unref(isInvalid))
                    ? (openBlock(true), createElementBlock(Fragment, { key: 1 }, renderList(unref(invalidFeedback), (feedback) => {
                        return (openBlock(), createElementBlock("div", {
                            key: feedback,
                            class: "invalid-feedback"
                        }, toDisplayString(feedback), 1 /* TEXT */));
                    }), 128 /* KEYED_FRAGMENT */))
                    : createCommentVNode("v-if", true),
                (unref(isValid))
                    ? (openBlock(true), createElementBlock(Fragment, { key: 2 }, renderList(unref(validFeedback), (feedback) => {
                        return (openBlock(), createElementBlock("div", {
                            key: feedback,
                            class: "valid-feedback"
                        }, toDisplayString(feedback), 1 /* TEXT */));
                    }), 128 /* KEYED_FRAGMENT */))
                    : createCommentVNode("v-if", true),
                (__props.helpText)
                    ? (openBlock(), createElementBlock("div", _hoisted_3$3, toDisplayString(__props.helpText), 1 /* TEXT */))
                    : createCommentVNode("v-if", true)
            ]));
        };
    }
});

script$d.__file = "src/components/FormGroup/FormGroup.vue";

const _hoisted_1$6 = ["for"];
const _hoisted_2$5 = ["id"];
const _hoisted_3$2 = {
    key: 0,
    class: "form-image-btn-edit"
};
var script$c = /*#__PURE__*/ defineComponent({
    __name: 'FormImage',
    props: Object.assign(Object.assign({ 
        /**
         * The data type of the model
         * @values 'file'|'base64'
         */
        dataType: {
            type: String,
            default: 'base64',
        } }, idProps), { 
        /**
         * The model value
         */
        modelValue: {
            type: [Object, String],
            default: undefined,
        }, 
        /**
         * The preview
         */
        preview: {
            type: String,
            default: undefined,
        } }),
    emits: ["update:modelValue"],
    setup(__props, { emit }) {
        const props = __props;
        // Rollup cannot handle HTMLInputElement as ref, cannot
        const input = ref();
        const file = ref();
        const readerResult = ref();
        const preview = computed(() => readerResult.value || props.preview);
        const style = computed(() => {
            if (!preview.value) {
                return {};
            }
            return {
                'background-color': 'transparent',
                'background-image': `url(${preview.value})`,
                'background-size': 'cover',
            };
        });
        const value = computed({
            get: () => props.modelValue,
            set: (v) => emit('update:modelValue', v),
        });
        watch(file, f => readFile(f));
        const onChange = (e) => {
            const newFile = e.target.files.item(0);
            if (newFile === null || newFile === void 0 ? void 0 : newFile.type.match('image.*')) {
                file.value = newFile;
                return true;
            }
            return false;
        };
        const onDrop = (e) => {
            e.preventDefault();
            input.value.files = e.dataTransfer.files;
            onChange({ target: input.value });
        };
        const readFile = (file) => {
            if (!file) {
                return value.value = undefined;
            }
            if (props.dataType === 'file') {
                value.value = file;
            }
            const reader = new FileReader();
            reader.onload = () => {
                readerResult.value = reader.result;
                if (props.dataType === 'base64') {
                    value.value = reader.result;
                }
            };
            reader.readAsDataURL(file);
            return reader;
        };
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("label", {
                class: normalizeClass(["form-image", { 'form-image-has-preview': !!unref(preview) }]),
                for: _ctx.id,
                style: normalizeStyle(unref(style)),
                onDrop: onDrop,
                onDragenter: _cache[0] || (_cache[0] = withModifiers(() => { }, ["prevent"])),
                onDragover: _cache[1] || (_cache[1] = withModifiers(() => { }, ["prevent"]))
            }, [
                createElementVNode("input", {
                    id: _ctx.id,
                    ref_key: "input",
                    ref: input,
                    accept: "image/*",
                    hidden: "",
                    type: "file",
                    onChange: onChange
                }, null, 40 /* PROPS, HYDRATE_EVENTS */, _hoisted_2$5),
                (unref(preview))
                    ? (openBlock(), createElementBlock("div", _hoisted_3$2))
                    : (openBlock(), createElementBlock(Fragment, { key: 1 }, [
                        createCommentVNode(" @slot Displays the placeholder "),
                        renderSlot(_ctx.$slots, "placeholder")
                    ], 2112 /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */))
            ], 46 /* CLASS, STYLE, PROPS, HYDRATE_EVENTS */, _hoisted_1$6));
        };
    }
});

script$c.__file = "src/components/FormImage/FormImage.vue";

const _hoisted_1$5 = ["for"];
const _hoisted_2$4 = { class: "list-unstyled d-flex align-content-start flex-wrap mb-0" };
const _hoisted_3$1 = { class: "form-pill-text" };
const _hoisted_4 = ["onClick"];
const _hoisted_5 = { class: "form-pill-input-item" };
const _hoisted_6 = { class: "form-pill-input-sizer overflow-hidden" };
const _hoisted_7 = ["id", "placeholder"];
var script$b = /*#__PURE__*/ defineComponent({
    __name: 'FormPills',
    props: Object.assign(Object.assign({ 
        /**
         * Defines if items should be removed when pressing backspace
         */
        editItemOnBackspace: {
            type: Boolean,
            default: false,
        } }, idProps), { 
        /**
         * The maximym amount of items that can be added to the list
         */
        maxItems: {
            type: Number,
            default: Infinity,
        }, 
        /**
         * The model value
         */
        modelValue: {
            type: Array,
            default: () => [],
        }, 
        /**
         * The placeholder for the input
         */
        placeholder: {
            type: String,
            default: '',
        }, 
        /**
         * The separator that checks if an item should be separated from the next one
         */
        separator: {
            type: [String, RegExp],
            // For some reason it does not allow RegExp to be used as default value.
            // eslint-disable-next-line vue/require-valid-default-prop
            default: /[\s\n]+/,
        }, 
        /**
         * The key to press to submit an item
         */
        submitKeys: {
            type: Array,
            default: () => ['Enter'],
        }, 
        /**
         * The matcher to check if an item is valid
         */
        valueMatcher: {
            type: [String, RegExp],
            // For some reason it does not allow RegExp to be used as default value.
            // eslint-disable-next-line vue/require-valid-default-prop
            default: /^.+$/,
        } }),
    emits: [
        /**
         * Fired when the model value is updated
         * @param {string[]} value The new value
         */
        'update:modelValue',
    ],
    setup(__props, { emit }) {
        const props = __props;
        const value = ref('');
        const clearValue = () => value.value = '';
        const items = computed({
            get: () => props.modelValue,
            set: (v) => emit('update:modelValue', v),
        });
        const maxItemsReached = computed(() => items.value.length >= props.maxItems);
        const matchItem = (item) => !!item.match(props.valueMatcher);
        const splitItem = (item) => item.split(props.separator);
        const removeItem = (index) => items.value.splice(index, 1);
        const validateValue = (value) => {
            if (Array.isArray(value)) {
                return value.every(validateValue);
            }
            return matchItem(value);
        };
        const addItem = (item) => {
            if (maxItemsReached.value) {
                return false;
            }
            const newItems = splitItem(item).filter(matchItem);
            if (newItems.length === 0) {
                return false;
            }
            const allowedItems = newItems.slice(0, props.maxItems - items.value.length);
            items.value = items.value.concat(allowedItems);
            return true;
        };
        watch(value, (v) => {
            const splitItems = splitItem(v);
            if (splitItems.length > 1
                && splitItems.filter(validateValue).length === splitItems.filter(v => v !== '').length) {
                addItem(v);
                clearValue();
            }
        });
        // We need to pass the Focus Event to the blur method in order for the test to
        // be able to mock the blur method.
        const blur = (event) => {
            const splitItems = splitItem(value.value);
            if (validateValue(splitItems)) {
                addItem(value.value);
                clearValue();
            }
        };
        const keydown = (event) => {
            if (event.code === 'Backspace') {
                if (value.value !== '') {
                    return;
                }
                const [removedItem] = removeItem(items.value.length - 1);
                if (props.editItemOnBackspace && removedItem) {
                    value.value = removedItem;
                    event.preventDefault();
                }
                return;
            }
            // If the max allowed items has been reached, don't allow any more typing.
            if (maxItemsReached.value) {
                event.preventDefault();
                return;
            }
            if (props.submitKeys.includes(event.code)) {
                const splitItems = splitItem(value.value);
                if (validateValue(splitItems)) {
                    addItem(value.value);
                    clearValue();
                }
                event.preventDefault();
            }
        };
        const paste = (event) => {
            event.preventDefault();
            const pasteValue = event.clipboardData.getData('text');
            if (!pasteValue) {
                return;
            }
            const newValue = value.value + pasteValue;
            const splitItems = splitItem(newValue);
            // If the input value together with the paste value are valid, add the items,
            // otherwise concat the paste value to the input value.
            if (validateValue(splitItems)) {
                addItem(newValue);
                clearValue();
            }
            else {
                value.value = newValue;
            }
        };
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("label", {
                class: "form-control",
                for: _ctx.id
            }, [
                createElementVNode("ul", _hoisted_2$4, [
                    (openBlock(true), createElementBlock(Fragment, null, renderList(__props.modelValue, (item, i) => {
                        return (openBlock(), createElementBlock("li", {
                            key: i,
                            class: "form-pill d-inline-flex align-items-center mw-100"
                        }, [
                            createElementVNode("div", _hoisted_3$1, toDisplayString(item), 1 /* TEXT */),
                            createElementVNode("div", {
                                class: "form-pill-remove",
                                onClick: ($event) => (removeItem(i))
                            }, null, 8 /* PROPS */, _hoisted_4)
                        ]));
                    }), 128 /* KEYED_FRAGMENT */)),
                    createElementVNode("li", _hoisted_5, [
                        createElementVNode("div", _hoisted_6, toDisplayString(value.value), 1 /* TEXT */),
                        withDirectives(createElementVNode("input", {
                            id: _ctx.id,
                            "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => ((value).value = $event)),
                            class: "form-pill-input w-100",
                            type: "text",
                            placeholder: unref(items).length ? '' : __props.placeholder,
                            onBlur: _cache[1] || (_cache[1] = ($event) => (blur())),
                            onKeydown: _cache[2] || (_cache[2] = ($event) => (keydown($event))),
                            onPaste: _cache[3] || (_cache[3] = ($event) => (paste($event)))
                        }, null, 40 /* PROPS, HYDRATE_EVENTS */, _hoisted_7), [
                            [vModelText, value.value]
                        ])
                    ])
                ])
            ], 8 /* PROPS */, _hoisted_1$5));
        };
    }
});

script$b.__file = "src/components/FormPills/FormPills.vue";

const _hoisted_1$4 = ["disabled"];
const _hoisted_2$3 = ["selected", "value"];
var script$a = /*#__PURE__*/ defineComponent({
    __name: 'FormSelect',
    props: formSelectProps,
    setup(__props) {
        const props = __props;
        const { classes } = useFormSelect(props);
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("select", {
                class: normalizeClass(["form-select", unref(classes)]),
                disabled: _ctx.disabled
            }, [
                (openBlock(true), createElementBlock(Fragment, null, renderList(_ctx.items, (item) => {
                    return (openBlock(), createElementBlock("option", {
                        key: item.value,
                        selected: item.selected,
                        value: item.value
                    }, toDisplayString(item.label || item.value), 9 /* TEXT, PROPS */, _hoisted_2$3));
                }), 128 /* KEYED_FRAGMENT */))
            ], 10 /* CLASS, PROPS */, _hoisted_1$4));
        };
    }
});

script$a.__file = "src/components/FormSelect/FormSelect.vue";

const _hoisted_1$3 = {
    key: 0,
    class: "input-group-text"
};
const _hoisted_2$2 = {
    key: 0,
    class: "input-group-text"
};
var script$9 = /*#__PURE__*/ defineComponent({
    __name: 'InputGroup',
    props: Object.assign({ 
        /**
         * The text to prepend to the input
         */
        append: {
            type: String,
            default: undefined,
        }, 
        /**
         * The text to append to the input
         */
        prepend: {
            type: String,
            default: undefined,
        } }, sizeProps),
    setup(__props) {
        const props = __props;
        const { classes } = useClasses(computed(() => [
            useSize(props.size, 'input-group-{0}').sizeClass.value,
        ]));
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", {
                class: normalizeClass(["input-group", unref(classes)])
            }, [
                createCommentVNode(" @slot Displays the prepend of the input "),
                renderSlot(_ctx.$slots, "prepend", {}, () => [
                    (__props.prepend)
                        ? (openBlock(), createElementBlock("span", _hoisted_1$3, toDisplayString(__props.prepend), 1 /* TEXT */))
                        : createCommentVNode("v-if", true)
                ]),
                createCommentVNode(" @slot Displays the content of the input "),
                renderSlot(_ctx.$slots, "default"),
                createCommentVNode(" @slot Displays the append of the input "),
                renderSlot(_ctx.$slots, "append", {}, () => [
                    (__props.append)
                        ? (openBlock(), createElementBlock("span", _hoisted_2$2, toDisplayString(__props.append), 1 /* TEXT */))
                        : createCommentVNode("v-if", true)
                ])
            ], 2 /* CLASS */));
        };
    }
});

script$9.__file = "src/components/InputGroup/InputGroup.vue";

var script$8 = /*#__PURE__*/ defineComponent({
    __name: 'ListGroup',
    props: Object.assign(Object.assign({}, flushProps), { 
        /**
         * Defines if the list should be displayed horizontally
         */
        horizontal: {
            type: Boolean,
            default: false,
        }, 
        /**
         * Defines if the list should be numbered
         */
        numbered: {
            type: Boolean,
            default: false,
        } }),
    setup(__props) {
        const props = __props;
        const tag = computed(() => props.numbered ? 'ol' : 'ul');
        const { classes } = useClasses(computed(() => [
            useFlush(props.flush, 'list-group-{0}').flushClass.value,
            props.horizontal ? 'list-group-horizontal' : undefined,
            props.numbered ? 'list-group-numbered' : undefined,
        ]));
        return (_ctx, _cache) => {
            return (openBlock(), createBlock(resolveDynamicComponent(unref(tag)), {
                class: normalizeClass(["list-group", unref(classes)])
            }, {
                default: withCtx(() => [
                    createCommentVNode(" @slot Displays the content of the list group "),
                    renderSlot(_ctx.$slots, "default")
                ]),
                _: 3 /* FORWARDED */
            }, 8 /* PROPS */, ["class"]));
        };
    }
});

script$8.__file = "src/components/ListGroup/ListGroup.vue";

var script$7 = /*#__PURE__*/ defineComponent({
    __name: 'ListGroupItem',
    props: Object.assign(Object.assign(Object.assign({}, activeProps), disabledProps), { 
        /**
         * The tag to be used for the list group item
         */
        tag: {
            type: String,
            default: 'li',
        }, variant: variantProp('') }),
    setup(__props) {
        const props = __props;
        const { classes } = useClasses(computed(() => [
            ['a', 'button'].includes(props.tag) ? 'list-group-item-action' : undefined,
            useActive(props.active).activeClass.value,
            useDisabled(props.disabled).disabledClass.value,
            useVariant(props.variant, 'list-group-item-{0}').variantClass.value,
        ]));
        return (_ctx, _cache) => {
            return (openBlock(), createBlock(resolveDynamicComponent(__props.tag), {
                class: normalizeClass(["list-group-item", unref(classes)])
            }, {
                default: withCtx(() => [
                    createCommentVNode(" @slot Displays the content of the list group item "),
                    renderSlot(_ctx.$slots, "default")
                ]),
                _: 3 /* FORWARDED */
            }, 8 /* PROPS */, ["class"]));
        };
    }
});

script$7.__file = "src/components/ListGroupItem/ListGroupItem.vue";

var script$6 = /*#__PURE__*/ defineComponent({
    __name: 'Nav',
    props: {
        /**
         * Defines if the `nav-fill` class should be used
         */
        fill: {
            type: Boolean,
            default: false,
        },
        /**
         * Defines if the `nav-justified` class should be used
         */
        justified: {
            type: Boolean,
            default: false,
        },
        /**
         * Defines if the `nav-pills` class should be used
         */
        pills: {
            type: Boolean,
            default: false,
        },
        /**
         * Defines if the `nav-tabs` class should be used
         */
        tabs: {
            type: Boolean,
            default: false,
        },
        /**
         * Defines if the `flex-column` class should be used
         * *Displays items vertically*
         */
        vertical: {
            type: Boolean,
            default: false,
        },
    },
    setup(__props) {
        const props = __props;
        const { classes } = useClasses(computed(() => [
            props.fill ? 'nav-fill' : undefined,
            props.justified ? 'nav-justified' : undefined,
            props.pills ? 'nav-pills' : undefined,
            props.tabs ? 'nav-tabs' : undefined,
            props.vertical ? 'flex-column' : undefined,
        ]));
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("nav", {
                class: normalizeClass(["nav", unref(classes)])
            }, [
                createCommentVNode(" @slot Displays the content of the nav "),
                renderSlot(_ctx.$slots, "default")
            ], 2 /* CLASS */));
        };
    }
});

script$6.__file = "src/components/Nav/Nav.vue";

const _hoisted_1$2 = { class: "nav-item" };

function render(_ctx, _cache) {
  return (openBlock(), createElementBlock("li", _hoisted_1$2, [
    createCommentVNode(" @slot Displays the content of the nav item "),
    renderSlot(_ctx.$slots, "default")
  ]))
}

const script$5 = {};


script$5.render = render;
script$5.__file = "src/components/NavItem/NavItem.vue";

var script$4 = /*#__PURE__*/ defineComponent({
    __name: 'NavLink',
    props: Object.assign(Object.assign({}, activeProps), disabledProps),
    setup(__props) {
        const props = __props;
        const { classes } = useClasses(computed(() => [
            useActive(props.active).activeClass.value,
            useDisabled(props.disabled).disabledClass.value,
        ]));
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("a", {
                class: normalizeClass(["nav-link", unref(classes)]),
                href: "#"
            }, [
                createCommentVNode(" @slot Displays the content of the nav link "),
                renderSlot(_ctx.$slots, "default")
            ], 2 /* CLASS */));
        };
    }
});

script$4.__file = "src/components/NavLink/NavLink.vue";

const placements = ['start', 'end', 'top', 'bottom'];
var usePlacement = (placement, classTemplate) => {
    const { templatedString } = useStringTemplate(classTemplate, placement);
    return { placementClass: templatedString };
};
const placementProps = {
    placement: {
        type: String,
        default: 'start',
        validator: (v) => placements.includes(v),
    },
};

const _hoisted_1$1 = ["id", "data-bs-backdrop", "data-bs-scroll"];
const _hoisted_2$1 = {
    key: 0,
    class: "offcanvas-header"
};
const offcanvasEvents = ['show', 'shown', 'hide', 'hidden', 'hidePrevented'];
var script$3 = /*#__PURE__*/ defineComponent({
    __name: 'Offcanvas',
    props: Object.assign(Object.assign(Object.assign(Object.assign({ 
        /**
         * Defines if a backdrop should be shown
         */
        backdrop: {
            type: Boolean,
            default: true,
        }, 
        /**
         * The header text of the offcanvas
         */
        header: {
            type: String,
            default: undefined,
        } }, idProps), { 
        /**
         * Defines if the `offcanvas-body` class should be omitted
         */
        noBody: {
            type: Boolean,
            default: false,
        } }), placementProps), { 
        /**
         * Defines if the main content should be scrollable when offcanvas is opened
         */
        scroll: {
            type: Boolean,
            default: false,
        }, 
        /**
         * Defines if the offcanvas is shown
         */
        show: {
            type: Boolean,
            default: false,
        } }),
    setup(__props, { expose, emit }) {
        const props = __props;
        const offcanvas = ref();
        useBootstrapEmits(offcanvas, offcanvasEvents, emit, 'offcanvas');
        const { bsInstance: bsOffcanvas } = useBootstrapInstance('Offcanvas', offcanvas);
        const { classes } = useClasses(computed(() => [
            usePlacement(props.placement, 'offcanvas-{0}').placementClass.value,
            computed(() => props.show ? 'show' : undefined).value,
        ]));
        expose({ bsOffcanvas });
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", {
                id: _ctx.id,
                ref_key: "offcanvas",
                ref: offcanvas,
                class: normalizeClass(["offcanvas", unref(classes)]),
                "data-bs-backdrop": __props.backdrop,
                "data-bs-scroll": __props.scroll
            }, [
                (!!_ctx.$slots.header || !!__props.header)
                    ? (openBlock(), createElementBlock("div", _hoisted_2$1, [
                        createCommentVNode(" @slot Displays content inside the header of the offcanvas "),
                        renderSlot(_ctx.$slots, "header", {}, () => [
                            createTextVNode(toDisplayString(__props.header), 1 /* TEXT */)
                        ])
                    ]))
                    : createCommentVNode("v-if", true),
                createElementVNode("div", {
                    class: normalizeClass({ 'offcanvas-body': !__props.noBody })
                }, [
                    createCommentVNode(" @slot Displays the body of the offcanvas "),
                    renderSlot(_ctx.$slots, "default")
                ], 2 /* CLASS */)
            ], 10 /* CLASS, PROPS */, _hoisted_1$1));
        };
    }
});

script$3.__file = "src/components/Offcanvas/Offcanvas.vue";

const aligns = ['baseline', 'center', 'end', 'start', 'stretch'];
const alignProp = {
    type: String,
    default: undefined,
    validator: (a) => aligns.includes(a),
};
const gutterProp = {
    type: [Number, String],
    default: undefined,
};
const justifies = ['around', 'between', 'center', 'end', 'evenly', 'start'];
const justifyProp = {
    type: String,
    default: undefined,
    validator: (j) => justifies.includes(j),
};

const tagProps = {
    tag: {
        type: String,
        default: 'div',
    },
};

const propsAlign = breakpointProps(alignProp, 'align-{0}');
const propsCol = breakpointProps(colProp, 'cols-{0}');
const propsGutters = breakpointProps(gutterProp, 'gutters-{0}');
const propsGuttersX = breakpointProps(gutterProp, 'gutters-x-{0}');
const propsGuttersY = breakpointProps(gutterProp, 'gutters-y-{0}');
const propsJustify = breakpointProps(justifyProp, 'justify-{0}');
var script$2 = /*#__PURE__*/ defineComponent({
    __name: 'Row',
    props: Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({ align: alignProp }, propsAlign), { cols: colProp }), propsCol), { gutters: gutterProp }), propsGutters), { guttersX: gutterProp }), propsGuttersX), { guttersY: gutterProp }), propsGuttersY), { justify: justifyProp }), propsJustify), tagProps),
    setup(__props) {
        const props = __props;
        const alignProps = {
            sm: toRef(props, 'alignSm'),
            md: toRef(props, 'alignMd'),
            lg: toRef(props, 'alignLg'),
            xl: toRef(props, 'alignXl'),
            xxl: toRef(props, 'alignXxl'),
        };
        const alignClass = useStringTemplate('align-items-{0}', props.align).templatedString;
        const alignClasses = useBreakpoints(alignProps, 'align-items-{0}-{1}').breakpointClasses;
        const colProps = {
            sm: toRef(props, 'colsSm'),
            md: toRef(props, 'colsMd'),
            lg: toRef(props, 'colsLg'),
            xl: toRef(props, 'colsXl'),
            xxl: toRef(props, 'colsXxl'),
        };
        const colClass = useStringTemplate('row-cols-{0}', props.cols).templatedString;
        const colClasses = useBreakpoints(colProps, 'row-cols-{0}-{1}').breakpointClasses;
        const guttersProps = {
            sm: toRef(props, 'guttersSm'),
            md: toRef(props, 'guttersMd'),
            lg: toRef(props, 'guttersLg'),
            xl: toRef(props, 'guttersXl'),
            xxl: toRef(props, 'guttersXxl'),
        };
        const guttersClass = useStringTemplate('g-{0}', props.gutters).templatedString;
        const guttersClasses = useBreakpoints(guttersProps, 'g-{0}-{1}').breakpointClasses;
        const guttersXProps = {
            sm: toRef(props, 'guttersXSm'),
            md: toRef(props, 'guttersXMd'),
            lg: toRef(props, 'guttersXLg'),
            xl: toRef(props, 'guttersXXl'),
            xxl: toRef(props, 'guttersXXxl'),
        };
        const guttersXClass = useStringTemplate('gx-{0}', props.guttersX).templatedString;
        const guttersXClasses = useBreakpoints(guttersXProps, 'gx-{0}-{1}').breakpointClasses;
        const guttersYProps = {
            sm: toRef(props, 'guttersYSm'),
            md: toRef(props, 'guttersYMd'),
            lg: toRef(props, 'guttersYLg'),
            xl: toRef(props, 'guttersYXl'),
            xxl: toRef(props, 'guttersYXxl'),
        };
        const guttersYClass = useStringTemplate('gy-{0}', props.guttersY).templatedString;
        const guttersYClasses = useBreakpoints(guttersYProps, 'gy-{0}-{1}').breakpointClasses;
        const justifyProps = {
            sm: toRef(props, 'justifySm'),
            md: toRef(props, 'justifyMd'),
            lg: toRef(props, 'justifyLg'),
            xl: toRef(props, 'justifyXl'),
            xxl: toRef(props, 'justifyXxl'),
        };
        const justifyClass = useStringTemplate('justify-content-{0}', props.justify).templatedString;
        const justifyClasses = useBreakpoints(justifyProps, 'justify-content-{0}-{1}').breakpointClasses;
        const { classes } = useClasses(computed(() => [
            alignClass.value,
            ...alignClasses.value,
            colClass.value,
            ...colClasses.value,
            guttersClass.value,
            ...guttersClasses.value,
            guttersXClass.value,
            ...guttersXClasses.value,
            guttersYClass.value,
            ...guttersYClasses.value,
            justifyClass.value,
            ...justifyClasses.value,
        ]));
        return (_ctx, _cache) => {
            return (openBlock(), createBlock(resolveDynamicComponent(_ctx.tag), {
                class: normalizeClass(["row", unref(classes)])
            }, {
                default: withCtx(() => [
                    createCommentVNode(" @slot Displays content inside the row "),
                    renderSlot(_ctx.$slots, "default")
                ]),
                _: 3 /* FORWARDED */
            }, 8 /* PROPS */, ["class"]));
        };
    }
});

script$2.__file = "src/components/Row/Row.vue";

const _hoisted_1 = { key: 0 };
const _hoisted_2 = ["onClick"];
const _hoisted_3 = ["onClick"];
var script$1 = /*#__PURE__*/ defineComponent({
    __name: 'Table',
    props: {
        /**
         * The fields of the table
         */
        fields: {
            type: Array,
            required: false,
            default: undefined,
        },
        /**
         * The items that are shown in the table
         */
        items: {
            type: Array,
            default: () => [],
        },
        /**
         * Defines if multiple items can be sorted at once
         */
        multiSort: {
            type: Boolean,
            default: false,
        },
        /**
         * Defines if the `table-hover` class should be used
         */
        hover: {
            type: Boolean,
            default: false,
        },
        /**
         * Defines if the `table-click` class should be used
         */
        // $attrs doesn't return emitted events, so
        // we have to catch it as a prop
        // eslint-disable-next-line vue/prop-name-casing
        'onClick:row': {
            type: Function,
            default: undefined,
        },
        /**
         * The classes that will be forwarded to the tbody tr
         */
        tbodyTrClass: {
            type: [String, Array, Object],
            default: undefined,
        },
        /**
         * The classes that will be forwarded to the tbody tr
         */
        theadTrClass: {
            type: [String, Array, Object],
            default: undefined,
        },
    },
    emits: ["click:row", "sort"],
    setup(__props, { emit }) {
        const props = __props;
        const sorted = ref((props.fields || [])
            .filter(f => f.sortable && f.sort)
            .reduce((obj, item) => Object.assign(obj, { [item.key]: item.sort }), {}));
        const headers = computed(() => {
            if (props.fields) {
                return props.fields;
            }
            const first = props.items.find(i => i !== undefined);
            return first
                ? Object.keys(first)
                    .map(f => ({ key: f }))
                : [];
        });
        const sort = (field) => {
            if (!field.sortable) {
                return;
            }
            const key = field.key;
            const sort = sorted.value[key];
            if (props.multiSort) {
                if (sort === 'asc') {
                    sorted.value[key] = 'desc';
                }
                else if (sort === 'desc') {
                    delete sorted.value[key];
                }
                else {
                    sorted.value[key] = 'asc';
                }
            }
            else {
                sorted.value = {
                    [key]: sort === 'asc' ? 'desc' : 'asc',
                };
            }
            emit('sort', sorted.value);
        };
        const { classes } = useClasses(computed(() => [
            props.hover && 'table-hover',
            props['onClick:row'] && 'table-click',
        ]));
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("table", {
                class: normalizeClass(["table", unref(classes)])
            }, [
                (unref(headers).length)
                    ? (openBlock(), createElementBlock("thead", _hoisted_1, [
                        createElementVNode("tr", {
                            class: normalizeClass(__props.theadTrClass)
                        }, [
                            createCommentVNode("\n                @slot Displays the header of the table\n                @binding {string} key The key of the header\n                @binding {object} header The header object\n                "),
                            (openBlock(true), createElementBlock(Fragment, null, renderList(unref(headers), (header) => {
                                return renderSlot(_ctx.$slots, `header-${header.key}`, {
                                    key: `header-${header.key}`,
                                    header: header
                                }, () => [
                                    (openBlock(), createElementBlock("th", {
                                        key: header.key,
                                        class: normalizeClass({
                                            'table-heading-sortable': header.sortable,
                                            'table-heading-sortable-asc': sorted.value[header.key] === 'asc',
                                            'table-heading-sortable-desc': sorted.value[header.key] === 'desc',
                                        }),
                                        onClick: ($event) => (sort(header))
                                    }, [
                                        createCommentVNode("\n                        @slot Displays the content of the table header\n                        @binding {object} header The header object\n                        "),
                                        renderSlot(_ctx.$slots, `header-${header.key}-content`, { header: header }, () => [
                                            createTextVNode(toDisplayString(header.label || header.key), 1 /* TEXT */)
                                        ])
                                    ], 10 /* CLASS, PROPS */, _hoisted_2))
                                ]);
                            }), 128 /* KEYED_FRAGMENT */))
                        ], 2 /* CLASS */)
                    ]))
                    : createCommentVNode("v-if", true),
                createElementVNode("tbody", null, [
                    createCommentVNode("\n            @slot Displays as the top row of the table\n            @binding {object[]} headers The headers of the table\n            "),
                    renderSlot(_ctx.$slots, "top-row", { headers: unref(headers) }),
                    createCommentVNode("\n            @slot Displays if there are no items in the table\n            @binding {object[]} headers The headers of the table\n            "),
                    (!__props.items.length)
                        ? renderSlot(_ctx.$slots, "no-items", {
                            key: 0,
                            headers: unref(headers)
                        })
                        : (openBlock(true), createElementBlock(Fragment, { key: 1 }, renderList(__props.items, (item, index) => {
                            return (openBlock(), createElementBlock(Fragment, {
                                key: `item-${index}`
                            }, [
                                createCommentVNode("\n                @slot Displays the row of the table\n                @binding {object} item The item object\n                @binding {int} index The index of the item\n                "),
                                renderSlot(_ctx.$slots, "row", {
                                    item: item,
                                    index: index
                                }, () => [
                                    createElementVNode("tr", {
                                        class: normalizeClass(__props.tbodyTrClass),
                                        onClick: ($event) => (_ctx.$emit('click:row', item))
                                    }, [
                                        createCommentVNode("\n                        @slot Displays the content of the table row\n                        @binding {any} key The key of the header\n                        @binding {object} field The header object\n                        @binding {object} item The item of the row\n                        @binding {int} index The index of the item of the row\n                        @binding {any} value The value that should be displayed\n                        "),
                                        (openBlock(true), createElementBlock(Fragment, null, renderList(unref(headers), (header) => {
                                            return renderSlot(_ctx.$slots, header.key, {
                                                key: header.key,
                                                field: header,
                                                item: item,
                                                index: index,
                                                value: item[header.key]
                                            }, () => [
                                                (openBlock(), createElementBlock("td", {
                                                    key: `item-${index}-${header}`
                                                }, [
                                                    createCommentVNode("\n                                @slot Displays the content of the table row\n                                @binding {any} field The header object\n                                @binding {object} item The item of the row\n                                @binding {int} index The index of the item of the row\n                                @binding {any} value The value that should be displayed\n                                "),
                                                    renderSlot(_ctx.$slots, `${header.key}-content`, {
                                                        field: header,
                                                        item: item,
                                                        index: index,
                                                        value: item[header.key]
                                                    }, () => [
                                                        createTextVNode(toDisplayString(item[header.key]), 1 /* TEXT */)
                                                    ])
                                                ]))
                                            ]);
                                        }), 128 /* KEYED_FRAGMENT */))
                                    ], 10 /* CLASS, PROPS */, _hoisted_3)
                                ])
                            ], 64 /* STABLE_FRAGMENT */));
                        }), 128 /* KEYED_FRAGMENT */)),
                    createCommentVNode("\n            @slot Displays as the bottom row of the table\n            @binding {object[]} headers The headers of the table\n            "),
                    renderSlot(_ctx.$slots, "bottom-row", { headers: unref(headers) })
                ])
            ], 2 /* CLASS */));
        };
    }
});

script$1.__file = "src/components/Table/Table.vue";

const tooltipFallbackPlacements = ['top', 'bottom', 'left', 'right'];
const tooltipPlacements = [...tooltipFallbackPlacements, 'auto'];
const tooltipFallbackPlacementProps = {
    fallbackPlacements: {
        type: Array,
        default: () => ['top', 'right', 'bottom', 'left'],
        validator: (v) => v.every(p => tooltipFallbackPlacements.includes(p)),
    },
};
const tooltipPlacementProps = {
    placement: {
        type: String,
        default: 'top',
        validator: (v) => tooltipPlacements.includes(v),
    },
};

const triggers = ['click', 'hover', 'focus', 'manual'];
const triggerProps = {
    trigger: {
        type: [String, Array],
        default: ['hover', 'focus'],
        validator: (v) => {
            if (Array.isArray(v)) {
                return v.every(t => triggers.includes(t));
            }
            return triggers.includes(v);
        },
    },
};

const tooltipEvents = ['show', 'shown', 'hide', 'hidden', 'inserted'];
var script = /*#__PURE__*/ defineComponent({
    __name: 'Tooltip',
    props: Object.assign(Object.assign(Object.assign({ 
        /**
         * Overflow constraint boundary of the tooltip
         */
        boundary: {
            type: [String, Object],
            default: 'clippingParents',
        }, 
        /**
         * Appends the tooltip to the given element
         */
        container: {
            type: [String, Object, Boolean],
            default: false,
        }, 
        /**
         * The classes that will be forwarded to the tooltip
         */
        customClass: {
            type: [String, Array, Object],
            default: '',
        }, 
        /**
         * Delay showing and hiding the tooltip in milliseconds
         */
        delay: {
            type: [Number, Object],
            default: 0,
        }, 
        /**
         * Defines if HTML is allowed in the tooltip
         */
        html: {
            type: Boolean,
            default: false,
        }, 
        /**
         * The x, y offset of the tooltip
         */
        offset: {
            type: [String, Array],
            default: () => [0, 0],
        }, 
        /**
         * Change Bootstrap's default Popper config
         */
        popperConfig: {
            type: [Object, Function],
            default: () => ({}),
        }, 
        /**
         * The tag to be used for the list group item
         */
        tag: {
            type: String,
            default: 'div',
        }, 
        /**
         * The text to display in the tooltip
         */
        title: {
            type: String,
            default: '',
        } }, tooltipFallbackPlacementProps), tooltipPlacementProps), triggerProps),
    setup(__props, { expose, emit }) {
        const props = __props;
        const tooltip = ref();
        const tooltipClass = computed(() => {
            if (typeof props.customClass === 'string') {
                return props.customClass;
            }
            if (Array.isArray(props.customClass)) {
                return props.customClass.join(' ');
            }
            return Object.keys(props.customClass)
                .filter((key) => !!props.customClass[key])
                .join(' ');
        });
        const tooltipTriggers = computed(() => {
            if (Array.isArray(props.trigger)) {
                return props.trigger.join(' ');
            }
            return props.trigger;
        });
        useBootstrapEmits(tooltip, tooltipEvents, emit, 'tooltip');
        const { bsInstance: bsTooltip } = useBootstrapInstance('Tooltip', tooltip, Object.assign(Object.assign({}, props), { customClass: tooltipClass.value, trigger: tooltipTriggers.value }));
        expose({ bsTooltip });
        return (_ctx, _cache) => {
            return (openBlock(), createBlock(resolveDynamicComponent(__props.tag), {
                ref_key: "tooltip",
                ref: tooltip
            }, {
                default: withCtx(() => [
                    createCommentVNode(" @slot Displays the content of the tooltip "),
                    renderSlot(_ctx.$slots, "default")
                ]),
                _: 3 /* FORWARDED */
            }, 512 /* NEED_PATCH */));
        };
    }
});

script.__file = "src/components/Tooltip/Tooltip.vue";

export { script$D as Accordion, script$C as AccordionItem, script$B as Alert, script$A as Badge, script$z as Breadcrumb, script$y as BreadcrumbItem, script$x as Button, script$w as ButtonClose, script$v as ButtonGroup, script$t as ButtonState, script$s as Card, script$r as Carousel, script$q as Col, script$p as Collapse, script$n as Confirm, script$m as Container, script$j as Dropdown, script$k as DropdownMenu, script$l as DropdownMenuItem, script$i as FormCheck, script$h as FormCheckGroup, script$g as FormControl, script$f as FormDropdown, script$e as FormDropdownSearch, script$d as FormGroup, script$c as FormImage, script$b as FormPills, script$a as FormSelect, script$9 as InputGroup, script$8 as ListGroup, script$7 as ListGroupItem, script$o as Modal, script$6 as Nav, script$5 as NavItem, script$4 as NavLink, script$3 as Offcanvas, script$2 as Row, script$u as Spinner, script$1 as Table, script as Tooltip, activeProps, breakpointProps, breakpoints, colProp, disabledProps, dropdownItemsProps, flushProps, formControlProps, idProps, sizeProps, sizes, tagProps, types, useActive, useBootstrap, useBootstrapEmits, useBootstrapInstance, useBreakpoints, useClasses, useDisabled, useFlush, useSize, useStringTemplate, useVariant, variantProp, variantProps, variants };
